#!/usr/bin/env python3
from .utils import *
from typing import Callable
# from data_file import iedb, ebola

class AirrFile():
    def __init__(self, path: str, use_v: bool = True, use_j: bool = False, use_allele: bool = False):
        self.file = pd.read_csv(path, sep = '\t')
        self.use_v = use_v
        self.use_j = use_j
        self.use_allele = use_allele
        self.dbs = {}
        self.__init__ = handle_error(self.__init__)
        self.process = handle_error(self.process)
        self.add_db = handle_error(self.add_db)
        self.query_db = handle_error(self.query_db)
    def rename(self, rename: dict):
        self.file.rename(columns = rename, inplace=True)
    def process(self):
        self.master = make_hash(self.file, use_v = self.use_v, use_j = self.use_j, allele = self.use_allele)
    def add_db(self, path: str, name: str):
        self.dbs[name] = make_hash(pd.read_csv(path, sep = '\t'), use_v = self.use_v, use_j = self.use_j, allele = self.use_allele)
    def query_db(self, name: str, column_name: str, threshold: float = 0.7, function: Callable = ratio,
                 use_threshold: bool = True, annot_func: Callable = lambda x:','.join(x)):
        if name not in self.dbs:
            return logging.error(f"The database name you provided for query func doesn't exist, run add_db before.")
        else:
            hits = search_two_dbs(self.master, self.dbs[name], threshold = threshold,
                                  score_func = function, use_threshold = use_threshold)
            self.file = annotate_og_file(self.file, hits, column_name = column_name, annot_func=annot_func)

class ObjectSet():
    def __init__(self, path: str, db: list, names: list, use_v: bool = True, use_j: bool = False):
        airr_f = AirrFile(path, use_v = use_v, use_j = use_j)
        airr_f.process()
        for db_path, db_name in zip(db, names):
            if os.path.exists(db_path) is False:
                return 'No database found.'
            airr_f.add_db(db_path, db_name)
        self.airr_f = airr_f
    def query_db(self, name: str, column_name: str, threshold: float = 0.7, function: Callable = ratio):
        self.airr_f.query_db(name, column_name, threshold, function)
    def save(self, path: str, delim: str = '\t'):
        self.airr_f.file.to_csv(path, sep = delim)



#!/usr/bin/env python3
from Levenshtein import ratio
from collections import defaultdict
from typing import DefaultDict, Callable
import pandas as pd
import logging
import requests
from functools import wraps

def download_covabdab(outf: str, filter_human: True) -> str:
    f = requests.get('https://opig.stats.ox.ac.uk/webapps/covabdab/static/downloads/CoV-AbDab_130623.csv')
    with open(outf, 'w') as k:
        k.write(f.content.decode())
    db = pd.read_csv(outf)
    if filter_human:
        db = db[(db['Heavy V Gene'].str.contains('Human'))&(db["Origin"].str.contains('Convalescent|Vaccinee|Human'))]
    db['v_call'] = db['Heavy V Gene'].map(lambda x:x.split(' (')[0])
    db['j_call'] = db['Heavy J Gene'].map(lambda x:x.split(' (')[0])
    db['cdr3_aa'] = db['CDRH3']
    hash = make_hash(db, allele = False, sequence_id = 'Name')
    return hash

def unpack_genes(v_field: str) -> str:
    return ','.join(set([p.split('*')[0] for p in v_field.split(',')]))

def make_hash(dataframe: pd.DataFrame, v_field: str = 'v_call', cdr3_field: str = 'cdr3_aa',
              allele: bool = True, sequence_id: str = 'sequence_id', use_v: bool = True,
              use_j: bool = False, j_field: str = 'j_call') -> DefaultDict:
    '''

    :param dataframe:
    :param v_field:
    :param cdr3_field:
    :param allele:
    :param sequence_id:
    :param use_j:
    :param j_field:
    :return: Dictionary with keys equal to V, (J), CDR3 Length,
    '''
    group = ['cdr3_length']
    dataframe = dataframe[(dataframe[cdr3_field].notna())&(dataframe[v_field].notna())]
    dataframe['cdr3_length'] = dataframe[cdr3_field].fillna('').map(len)
    if use_v:
        group.append('v')
        if allele:
            dataframe['v'] = dataframe[v_field]
        else:
            dataframe['v'] = dataframe[v_field].map(unpack_genes)
        array = dataframe[[sequence_id, 'cdr3_length', cdr3_field, 'v']].values
    else:
        array = dataframe[[sequence_id, 'cdr3_length', cdr3_field]].values
    if use_j:
        group.append('j')
        if allele:
            dataframe['j'] = dataframe[j_field]
        else:
            dataframe['j'] = dataframe[j_field].map(unpack_genes)
        array = dataframe[[sequence_id, 'cdr3_length', cdr3_field, 'v', 'j']].values
    output = defaultdict(lambda: defaultdict(set))
    for row in array:
        if use_v:
            for v in set(row[3].split(',')):
                if use_j:
                    for j in set(row[4].split(',')):
                        output[(v, j, row[1])][row[2]].add(row[0])
                else:
                    output[(v, row[1])][row[2]].add(row[0])
        else:
            output[(row[1])][row[2]].add(row[0])
    return output

def search_two_dbs(hash1: dict, hash2: dict, threshold: float = .7, score_func: Callable = ratio,
                   use_threshold: bool = True) -> DefaultDict:
    overlap = set(hash1.keys()).intersection(set(hash2.keys()))
    if use_threshold:
        matches = defaultdict(set)
    else:
        matches = defaultdict(lambda: defaultdict(int))
    for key in overlap:
        h3s_1 = hash1[key]
        h3s_2 = hash2[key]
        for h3_1 in h3s_1:
            for h3_2 in h3s_2:
                match = False
                if use_threshold:
                    if h3_1 == h3_2:
                        match = True
                    elif score_func(h3_1, h3_2) >= threshold:
                        match = True
                    if match:
                        for entry1 in hash1[key][h3_1]:
                            matches[entry1].update(hash2[key][h3_2])
                else:
                    score = score_func(h3_1, h3_2)
                    for entry1 in hash1[key][h3_1]:
                        for entry2 in hash2[key][h3_2]:
                            matches[entry1][entry2] = score
    return matches

def annotate_og_file(dataframe: pd.DataFrame, matches: DefaultDict, sequence_id: str = 'sequence_id', column_name: str = 'query',
                     annot_func: Callable = lambda x:','.join(x)) -> pd.DataFrame:
    dataframe[column_name] = dataframe[sequence_id].map(matches).map(annot_func)
    return dataframe

def handle_error(func: Callable) -> Callable:
    @wraps(func)
    def handle(*args, **kwargs):
        try:
            return func(*args, **kwargs)
        except Exception as e:
            logging.error(f"Error in: {func.__name__}: {e}")
            raise
    return handle



##Precomputed hashes!


iedb = {('IGHV1-69', 20): {'AREGTTGWGWLGKPIGAFAH': {27},
  'AREGTTGAGWLGKPIGAFAH': {356},
  'VRSVTPRYCGGGFCYGEFDY': {674},
  'AREGTTGSGWLGKPIGAFAY': {821},
  'AREGTTGWGWLGKPIGAFQH': {822},
  'AREGTTGDGDLGKPIGAFAH': {978},
  'AREGTTGWGWLGKPIGAFAY': {9240},
  'AREGGHQGYCSGGSCYDFDY': {19788},
  'ARDWPSITVAVDATNYGMDV': {211511}},
 ('IGHV3-30', 19): {'AILLSAGAANLDNNYGMDV': {31},
  'ARELLMDYYDHIGYSPGPT': {523},
  'ATDKTYVSGYTSTWYYFNY': {26784}},
 ('IGHV3-23', 22): {'SRYSSYYSYYYSSSSYSYAMDY': {46},
  'VRVTFYHEGSGYYYRAGNYFDS': {909},
  'ARGYYYTGLWYPYAMYEFGMDY': {8675}},
 ('IGHV3-66', 14): {'ARWGHSTSPWAMDY': {48}},
 ('IGHV3-23', 13): {'ARFVFFLPYAMDY': {49},
  'AKPNVGSGWSFDS': {168},
  'ARHPYWYGGQLDL': {862},
  'ARIKLGTVTTVDY': {876},
  'ASSYDFWSNAFDI': {1260},
  'VRDRSNGWSSINL': {19588},
  'ARDLVLGSGSSND': {202254}},
 ('IGHV3-30', 18): {'ARDGKCGGGRCYSGLLDY': {136},
  'AVPGPVFGIFPPWSYFDN': {605},
  'AREGLSRDNSGFTGLIDY': {19711},
  'AREGLSREKNGYSGLIDY': {201044},
  'ARDGTCGGGNCYSGLLDY': {201045}},
 ('IGHV1-69D', 14): {'AKHMGYQVRETMDV': {143},
  'ARYFDTYNNYGFAN': {393},
  'ARHGNYYYYSGMDV': {501},
  'ARRPQSIFDWNFDL': {923},
  'ARDPSFWAAEYFQH': {19661},
  'ARSCGDCYSADLDF': {202257}},
 ('IGHV4-39', 15): {'ARLGPDDYTLDGMDV': {161},
  'ARHRRVLLWFGEFQL': {19683},
  'ARQWKWFGEAWYFDL': {202256}},
 ('IGHV3-30', 15): {'ARGLGAFHWDMQPDY': {164},
  'ANNNGQQLVYSYMDV': {179},
  'ARDLGGYFIRGIMDV': {749},
  'AKDWALFRWLRTFDH': {19641},
  'ARDPIVGHTRDGLDV': {19784}},
 ('IGHV1-3', 21): {'ARGRRDVRGVLWRGRHDYFDF': {169},
  'ARDKVDDYGDYWFPTLWYFDY': {1299}},
 ('IGHV4-59', 19): {'ARVAIGVSGFLNYYYYMDV': {170},
  'ARRRSDFETVDFIYHYMDV': {900},
  'VRASRSYYWGSYRPTAFDS': {1033}},
 ('IGHV3-23', 11): {'ARDLIHGVTRN': {188},
  'ARGGPDYAMDV': {478},
  'ATEGDNDAFDI': {748},
  'ARVGLGDAFDI': {965},
  'ARRHWPGGFDY': {19639}},
 ('IGHV1-18', 14): {'ARGPKEQVVRWFDP': {189}, 'TRGKNCDYNWDFEH': {361}},
 ('IGHV3-9', 16): {'AKTRSYVVAAEYYFHY': {193}},
 ('IGHV1-69', 13): {'ASTLGLVLDAMDY': {196}, 'TSGYWNSPTDFHY': {28001}},
 ('IGHV3-23', 21): {'ARPYLTYPQRRGPQNVSPFDN': {199},
  'AGYDSGYDYVAVAGPAEYFQH': {484},
  'ARGIWSYWYMVYPHDNYGMDY': {1344}},
 ('IGHV3-48', 8): {'ARGRFFDY': {203}},
 ('IGHV3-23', 10): {'ARSARFSFDY': {205},
  'ARWWSSAMDY': {380},
  'ARWGDEGFDI': {739},
  'ARFYDSFFDI': {1003}},
 ('IGHV3-66', 10): {'ARFWWRSFDY': {206},
  'AKWAWPAFDY': {467},
  'ARYVYHALDY': {707},
  'ARGYGWALDY': {19753},
  'ARWSGTYYDY': {202253}},
 ('IGHV3-23', 16): {'ARGELPYYRMSKVMDV': {207},
  'AKFSGKDCSGTSCRDY': {8705},
  'AKDSGVGLALPINFDY': {8751},
  'ARLDSSGFHYGRPGRN': {26616}},
 ('IGHV3-66', 17): {'AREDFRNRRRLWYVMDY': {208},
  'ARYETLYWPYQNSGMDY': {866},
  'ARENADYGSDYYFGMDV': {924},
  'ARKQYSYWRDSYWAMDY': {1268},
  'ARSRGQASWDYWWAMDY': {19573}},
 ('IGHV3-48', 11): {'ARYYGTGAMDY': {209}},
 ('IGHV3-66', 18): {'ARRVCYNRLGVCAGGMDY': {213},
  'AREYHSYVYEPPLYGMDY': {19760},
  'ARGPNDYRNRKYYYYMDV': {28872}},
 ('IGHV3-48', 20): {'ARRSYDSSGYWGHFYSYMDV': {251},
  'ARRSYDSSGYAGHFYSYMDV': {252},
  'ARGGWALGDEIPSSFLEFDY': {19763}},
 ('IGHV1-69D', 13): {'ARYFMSYKHLSDY': {256}, 'ARGISGSYGWFDP': {544}},
 ('IGHV3-21', 16): {'ARKGSDRLSDNDPFDA': {284},
  'ARDPGIAAADNHWFDP': {19722},
  'ARNVLDSSGYPTYFDY': {28870}},
 ('IGHV4-30-4', 13): {'ARVSIFGVGTFDY': {289}},
 ('IGHV3-66', 16): {'ARNALYGSGGYYAMDY': {291},
  'ARVLSRASGMPDAFDI': {475},
  'YYHYYGWHPGYGLSYS': {549},
  'ARLTWRSYRGVHALDY': {1544}},
 ('IGHV3-66', 20): {'ARTYGIYDLYVDYTEYVMDY': {295},
  'AREYHSYWSYSWWPRVGLDY': {19761}},
 ('IGHV5-10-1', 14): {'ARLEPGYSSTWSVN': {300},
  'ARELYQGYMDTFDS': {483},
  'ARVQYSGYYDWFDP': {989}},
 ('IGHV3-23', 17): {'AKPWYPFMASKGSEFDY': {301},
  'VKDRVAVAGKGSYYFDS': {870},
  'ARDDDYEEWPWYYGMDV': {19723}},
 ('IGHV3-23', 15): {'ARDNGDYVGEKGFDI': {302},
  'ARDPGLWDYYYGMDV': {344},
  'AYRRIGVPRRDEFDI': {776},
  'AKDHRVWAAGYHFDY': {1962},
  'AKDHRVWAPGYYFDH': {1963},
  'AKDRGPRGVGELFDS': {19589},
  'AKVLSPGGSNMVWDY': {202270},
  'AKCWGRGSYSGIPDY': {206054}},
 ('IGHV1-69', 21): {'AGVYEGEADEGEYRNNGFLKH': {303},
  'AGVYEGEADEGEYDNNGFLKH': {353}},
 ('IGHV1-69D', 23): {'ASPYPNDXNDXAPEEGMSWYFDL': {304},
  'ARERGRHFEPKNRDNLEGKFFDL': {906},
  'ASPYPNDYNDYAPEEGMSWYFDL': {1219}},
 ('IGHV1-24', 18): {'ATGGNYYNLWTGYYPLAY': {305}, 'TTGDFSEFEPFSMDYFHF': {964}},
 ('IGHV3-74', 12): {'ARGSGFRWVMDY': {311}, 'ARGRWYRRALDY': {867}},
 ('IGHV2-26', 13): {'ARMGSDYDVWFDY': {312}},
 ('IGHV2-5', 13): {'ARLGSDYDVWFDY': {313}},
 ('IGHV3-66', 13): {'AREYYRWYTAIDY': {315},
  'ARTPWWYWSGLDY': {387},
  'ARRLALVRMWMDY': {9231},
  'ARFVNWDGDYMDY': {19706}},
 ('IGHV3-23', 12): {'AGELLPYYGMDV': {324},
  'ARGPFSPWVMDY': {367},
  'AKDLRLGGGSDY': {806},
  'ARYIDFGDHMDF': {8689},
  'AKEAYSARGFDY': {212143},
  'AKSRWGGYDFDY': {212144}},
 ('IGHV2-70', 16): {'ARTLRVSGDYVRDFDL': {326}},
 ('IGHV3-21', 22): {'ARDRPGGYCSGVSCYSTYGMDV': {332}},
 ('IGHV4-59', 2): {'AR': {335}},
 ('IGHV1-46', 16): {'ARDWGSNYVWGSYPKY': {339}},
 ('IGHV1-69', 24): {'ARHYEIQIGRYGMNVYYLMYRFAS': {341}},
 ('IGHV1-18', 18): {'ARDPAAWPLQQSLAWFDP': {345},
  'ARDVQYSGSYLGAYYFDY': {499},
  'TRGKYCTARDYYNWDFEH': {601}},
 ('IGHV5-51', 17): {'ARLGGDYEDSGADAFDF': {351},
  'TRLYLFEGAQSSNAFDL': {395},
  'AILGFWGANRGGGGMDV': {8704}},
 ('IGHV1-69D', 12): {'ARDNPTLLGSDY': {352},
  'AQGPIVGAPTDY': {586},
  'ARGPLSRGYYDY': {1353},
  'ARYDGIYGELDF': {1419}},
 ('IGHV1-3', 20): {'ARVGPYSWDDSPQDNYYMDV': {354}},
 ('IGHV3-15', 22): {'TTDGFIMIRGVSEDYYYYYMDV': {355},
  'ARTGKYYDFWSGYPPGEEYFQD': {524},
  'TTAGSYYYDTVGPGLPEGKFDY': {206063}},
 ('IGHV3-7', 22): {'AREFSSYTDHLEYYYDYYYMDV': {357}},
 ('IGHV4-59', 17): {'ARGPVPAVFYGDYRLDP': {358}, 'ATSYVDNWHAGLHWFDS': {19719}},
 ('IGHV3-30', 21): {'ARDIGLKGEHYDILTAYGPDY': {359}},
 ('IGHV1-69', 15): {'ARASYSSSSPYAFDI': {365},
  'ARDLTTLTSYNWWDL': {651},
  'VLLGTTMVTGHYFDY': {8698}},
 ('IGHV2-5', 24): {'AHRRGPTTLFGVPIARGPVNAMDV': {390}},
 ('IGHV1-69', 19): {'TRDRSRVRYFDRESGWFDP': {392},
  'ATLHPRLCRGGTCWGWFDP': {211442}},
 ('IGHV5-51', 19): {'ARLHYSDRSGSYFNDVFHM': {394},
  'ARLGGRYYHDSSGYYYLDY': {538},
  'ARLGGRYYYDSSGYYYFDY': {976},
  'ARLGGQLWNSYYYYYYMDV': {8746}},
 ('IGHV3-48', 13): {'ARERWHVRGYFDH': {407}},
 ('IGHV1-18', 15): {'AREPPLFYSSWSLDN': {410},
  'ARAQKRGRSEWAYAH': {636},
  'VRNVGTAGSLLHYDH': {1032},
  'ARDRPHILTGFDFDY': {1372},
  'ARDSSSSWARWFFDL': {1397},
  'ARVPANTLVNHDFDY': {8752}},
 ('IGHV3-30-3', 22): {'AKDSQLRSLLYFEWLSQGYFDP': {411},
  'AKDSQLRSLLYFEWLSQGYFDY': {412}},
 ('IGHV5-51', 12): {'VGLDWNYNPLRY': {413}, 'AGGSGISTPMDV': {59128}},
 ('IGHV1-2', 19): {'ARGGLEPRSVDYYYYGMDV': {415},
  'ARAGLEPRSVDYYFYGLDV': {519},
  'AREMFDSSADWSPWRGMVA': {1358}},
 ('IGHV3-23', 19): {'ARGKGNTHKPYGYVRYFDV': {424}},
 ('IGHV5-10-1', 20): {'AYHRRGHFYGSGSAWDWFES': {427}},
 ('IGHV4-38-2', 12): {'AGLTQSSHNDAN': {451}},
 ('IGHV3-66', 11): {'AKWWAWPAFDY': {466},
  'ARGYYGAAMDY': {918},
  'ATRNYRLYFDF': {8741}},
 ('IGHV3-74', 15): {'ARGLGKGSKRGAMDY': {477}, 'ARVIASPGISYGMDV': {206051}},
 ('IGHV6-1', 12): {'ARYSYPFYSIDY': {482}, 'ARGIVFSYAMDV': {1237}},
 ('IGHV4-39', 19): {'ARRQLLDDGTGYQWAAFDV': {491}},
 ('IGHV3-9', 20): {'AKDRLESSAMDILEGGTFDI': {498}},
 ('IGHV3-23', 26): {'AKHMSMQQVVSAGWERADLVGDAFDV': {504},
  'AKHMSMQQVPGSGWERADLVGDAFDV': {19608},
  'AKDVTYLYDSSGYYYGGADRDYYFDY': {201246}},
 ('IGHV4-4', 26): {'ARTLHGRRIYGIVAFNEWFTYFYMDV': {517},
  'ARAQQGKRIYGMVSFGEFFYYYYMDV': {998},
  'ARTQHGRRIYGIVAFREWFTYFYMDV': {19671}},
 ('IGHV3-66', 19): {'ARTVRGSKKPYFSGWAMDY': {534},
  'ARGSGHVNAVKNYGYVMDY': {1465},
  'ARYYSSGGSYYRYSRGFDY': {1555},
  'ARYKYPYWSWYYYWGGMDY': {19762}},
 ('IGHV3-66', 12): {'ARTWLLRWVMDL': {535},
  'ARSYSWSYAIDY': {1254},
  'ARSYSTKLAMDY': {19755},
  'ARHYSAVAGLDY': {19794}},
 ('IGHV1-2', 16): {'ARQKFYTGGQGWYFDL': {536}, 'VRRGSCDYCGDFPWQY': {662}},
 ('IGHV3-9', 13): {'AKDSPRGELPLNY': {539}, 'ARERLPGNWNYDL': {8739}},
 ('IGHV3-33', 23): {'ARQQDSGYSGPEVSYYSHYGMDV': {545}},
 ('IGHV1-69D', 16): {'ARVGGEWGSGRYYLDH': {546},
  'ARKLEPPYYFYSYMDV': {19698},
  'ARSRDLLLFPHHALSP': {19803}},
 ('IGHV1-2', 14): {'ARGKNSDYNWDFQH': {548},
  'ARGVRRDASWWLQF': {563},
  'ARGGMTMVRGVMMD': {896}},
 ('IGHV4-59', 15): {'ASLPRGQLVNAYFRN': {552}},
 ('IGHV1-2', 15): {'ARDESGDDLKWHLHP': {555},
  'ARRMRSQDREWDFQH': {638},
  'ARDRSYGDSSWALDA': {1356},
  'ARDRLYDGSSWRLDP': {1562},
  'ARDKYYGNEAVGMDV': {1574}},
 ('IGHV1-2', 12): {'ARQRSDYWDFDV': {556},
  'ARGFAGYEWSFI': {910},
  'ARERSDFWDFDL': {1581},
  'ARRHSDYCDFDI': {1582}},
 ('IGHV1-2', 18): {'ARGKYCTARDYYNWDFQH': {558},
  'VRTADCERDPCKGWVFPH': {891},
  'ARGKYCTASDYYNWDFEH': {1225}},
 ('IGHV1-2', 17): {'VRRGSSCPHCGDFHFEH': {562}, 'VRKGPSCPHCGDFHWQH': {889}},
 ('IGHV1-46', 13): {'ARGVVGATNEIDF': {564}},
 ('IGHV3-30', 30): {'AREAGGPIWHDDVKYXDFNDGYYNYHYMDV': {574},
  'VREAGGPDYRNGYNXXDFYDGYYNYHYMDV': {926},
  'AREAGGPIWHDDVKYYDFNDGYYNYHYMDV': {1333},
  'VREAGGPDYRNGYNYYDFYDGYYNYHYMDV': {1553}},
 ('IGHV1-69D', 19): {'ATETALVVSTTYLPHYFDN': {575},
  'ARTFHIRRYRSGYYDKMDH': {1349},
  'ATETALVVSETYLPHYFDN': {19587}},
 ('IGHV4-4', 20): {'ARHRHHDVFMLVPIAGWFDV': {587},
  'ARSGFCSDDACYRRGSWFDP': {19785}},
 ('IGHV1-69', 18): {'AREMEVSGRWRPTEAFEI': {590},
  'ARVGYCSSTSCNRGAFDI': {954},
  'AREGTTGSGGKPIGAFAH': {977}},
 ('IGHV3-9', 14): {'ARDMRAATPYSFDY': {591},
  'AKVSYLSTASSLDY': {844},
  'VKDKGWLIQGRFDS': {206055}},
 ('IGHV4-38-2', 17): {'ARHVRSGYPDTAYYFDK': {642}},
 ('IGHV3-21', 17): {'ARARATGYSSITPYFDI': {646}, 'ARARATGYNSITPYFDI': {8679}},
 ('IGHV3-30', 13): {'AKDLIESNIAEAF': {657},
  'ARASIAAARVLDY': {1282},
  'AKEGGDNKFSFDY': {19709},
  'ASGSDYGDYLLVY': {206064}},
 ('IGHV4-59', 26): {'ATTKHGRRIYGVVAFKEWFTYFYMDV': {666},
  'ATARRGQRIYGVVSFGEFFYYYYMDV': {824},
  'ATARRGQRIYGVVSFGEFFYYYSMDV': {1371}},
 ('IGHV1-3', 14): {'ARGASWDARGWSGY': {684},
  'ALLTVLTPDDAFDI': {19799},
  'ALLTVITPDDAFDI': {205970},
  'ALLTVITPDDTFDI': {205971},
  'ALMTVITPDDAFDI': {205986},
  'VLLTVLTPDDAFDI': {211864},
  'ALLTVLQPDDAFDI': {212017}},
 ('IGHV4-34', 19): {'ARGPLSRVRLLRGVVYFDS': {685},
  'ARALVRGISKTRPQRGLDP': {688}},
 ('IGHV4-34', 24): {'ARGLGITMVRGVISKNRQKYYFDY': {686}},
 ('IGHV4-34', 17): {'ARGDRQQLVRRYKWFDP': {687}},
 ('IGHV3-48', 17): {'ARGLTESLELTADWFDY': {690}, 'ASSKQQVSGGFYWYFDL': {202269}},
 ('IGHV3-33', 18): {'ARDKNPGTKPYYHYGMDV': {691},
  'AKESDSCGGDCSRFAFDV': {19710},
  'VKVEDYVRGSSHGGAFHI': {28850}},
 ('IGHV5-51', 23): {'ARQNHYGSGSYFYRTAYYYAMDV': {694}},
 ('IGHV3-20', 14): {'AKILGAGRGWYFDY': {697}},
 ('IGHV1-69-2', 12): {'AADPWELNAFNV': {715}},
 ('IGHV1-18', 19): {'ARVEGVRGVMGFHYYPMDV': {738},
  'ARDKVQGRVEVGSGGRHDY': {927}},
 ('IGHV1-24', 10): {'AVPDPDAFDI': {746}},
 ('IGHV1-69D', 25): {'AGPSITESHYCLDCAAKDYYYGLDV': {747}},
 ('IGHV3-21', 23): {'ARDRSYYAFSSGSLSDYYYGLDV': {764}},
 ('IGHV3-30', 22): {'AKDGAYYYDYSGYPYDYNGIDV': {795}},
 ('IGHV4-34', 13): {'ARRSNWPYLPFDP': {804}},
 ('IGHV1-18', 16): {'AKGLLRDGSSTWLPYL': {825}, 'ARALEMGHRSGFPFDY': {19819}},
 ('IGHV1-2', 24): {'ARDGAKTVSNSGLSLLYYHNRLDA': {826}},
 ('IGHV3-30', 17): {'ARWNNWNHRGMVFAFDL': {827},
  'ARDEWAVHDSYYYGMDV': {949},
  'AKDARDCLLCADWHFDL': {1306},
  'ARDGMGRSSGSFSAFDY': {22512},
  'AKEGHGSDMTWRADFDY': {202467}},
 ('IGHV3-74', 26): {'VRDGVRFYYDSTGYYPDSFFKYGMDV': {853},
  'ARDGVRYYYDSTGYYPDNFFQYGLDV': {854}},
 ('IGHV3-64', 15): {'VGGYSNFYYYYTMDV': {855}},
 ('IGHV4-39', 17): {'ASIYGSGTFYYYFYMDV': {860}, 'ARQGLTSSWYDGSGLDV': {211827}},
 ('IGHV3-66', 21): {'ARTGMYFGFFHHSWSNAALDY': {865},
  'ARQSSAEIESWYYYSGEAMDY': {19548}},
 ('IGHV3-7', 11): {'ARVSRGGSFSD': {871},
  'ARVSRGGSYSD': {872},
  'TRDRGWLTFDY': {212141}},
 ('IGHV3-23', 14): {'AKYTSPPQNHGFDY': {875},
  'AKAKRVGATGYFDL': {1183},
  'ARWIGSRELYIMDY': {19669},
  'TTLLIYESDVGVDF': {19735},
  'AKSRYSQYFYPFDY': {212145}},
 ('IGHV1-69', 22): {'ARGSHLYDFWSASHPPNDALAI': {878},
  'ARGSFDYYFWSASHPPNDALAI': {879},
  'AREGTTPPGWGWLGKPIGAFAH': {19557},
  'AREPLGYCSGGSCYPLHNGMDV': {26787}},
 ('IGHV1-2', 25): {'VRGKSCCGGRRYCNGADCFNWDFEH': {890},
  'VRGRSCCGGRRHCNGADCFNWDFQH': {892},
  'VRGKSCCNGRRYCNGADCFNWDFEY': {1587}},
 ('IGHV3-30', 14): {'ARSRGNHYYYGMDV': {895}, 'AKVGDGTVAGTIDY': {28868}},
 ('IGHV1-46', 18): {'ARDGLGEVAPDYRYGIDV': {907},
  'ARDGLGEVAPAYLYGIDA': {908},
  'ARAEAASDSHSRPIMFDH': {912}},
 ('IGHV1-6', 21): {'VKDQTIFHKNGAVDFFSYFDL': {911}},
 ('IGHV3-48', 10): {'ARTWYYGFDY': {919}},
 ('IGHV4-31', 14): {'ARVPRLRGGNYFDS': {921}, 'ARDRPDDPGPYFDS': {206056}},
 ('IGHV3-30', 16): {'ARDRIVDDYYYYGMDV': {925}},
 ('IGHV5-51', 18): {'ARHASCSARSCYWGPVDY': {928},
  'ARLGDVETAMVGQDAFHI': {942},
  'ARVVADREGFGYYYGMDV': {1259}},
 ('IGHV5-51', 14): {'ARPHYYDSLDAFDI': {931},
  'ARGTSTGLREAFHI': {19642},
  'ARVGPADVWDSFDY': {19736},
  'ARVGRPSKGGWFDP': {19848}},
 ('IGHV3-30', 8): {'ARDRYFDL': {932}, 'KTHGSHDN': {19752}},
 ('IGHV4-4', 16): {'ARVALFDILTGGWFDP': {934}, 'AREWAEDGDFGNAFHV': {1411}},
 ('IGHV3-11', 19): {'ARADGLTYFSELLQYIFDL': {935}},
 ('IGHV1-3', 18): {'ARDRGFDLLTGHYLGLDP': {936}},
 ('IGHV3-11', 14): {'VRDRDDFWSGYYKH': {938}},
 ('IGHV4-59', 12): {'ATRWNYFFDFDY': {941}},
 ('IGHV3-15', 17): {'FTAATNDYYDTYGYCDY': {943},
  'FTAAQNDYYDTYGYSDY': {945},
  'VTAATHDYYDTYGYSNY': {946},
  'VTAATNDYYDTHGYSNY': {951},
  'VTAATNDYYDTYGYSDY': {953}},
 ('IGHV1-18', 17): {'AREDWSYGDSYYNGMDV': {944}, 'GRDMLGVVQAVAGPFDS': {19780}},
 ('IGHV3-7', 18): {'ARQGSFADTYFYYYAMDV': {947},
  'ARQGSFGDTYFYYYAMDV': {948},
  'ARQGSFADTYYYYYAMDV': {950}},
 ('IGHV1-69-2', 14): {'ATVMGKWIKGGYDY': {960}},
 ('IGHV4-38-2', 21): {'ARFGGEVLVYRDWPKPAWVDL': {968},
  'ARFGGEVLRYTDWPKPAWVDL': {969}},
 ('IGHV3-74', 9): {'ARGDGGLDD': {971}, 'ARAGTLFAY': {984}},
 ('IGHV7-4-1', 11): {'AREGGARGFDY': {972}},
 ('IGHV7-4-1', 20): {'ATYYVDLWGSYRQDYYGMDV': {974}},
 ('IGHV1-46', 15): {'ARGAHRSIGTTPLDS': {975},
  'ARNVATEGSLLHYDY': {1030},
  'VRNVGTAGSLLHYDH': {1551}},
 ('IGHV4-61', 13): {'ARALLTTVTTFEY': {986}},
 ('IGHV3-23', 20): {'VRDDSYDGGGHYGLHNWFDS': {988},
  'ARAVVFTDSSAYYYSKYFDY': {1005},
  'ARAVVSSDITYTYWSKYFDY': {1603},
  'ARYGHWSWGRWWNYWVALDY': {8692},
  'ARDVRMCTSMSCSYYYGMDV': {28834},
  'AKAIIKCAPDACYYDDGMDV': {28835}},
 ('IGHV3-20', 26): {'ARGTDYTIDDQGIFYKGSGTFWYFDL': {999},
  'ARGTDYTIDDQGIRYQGSGTFWYFDV': {1000}},
 ('IGHV3-7', 14): {'ARNFVRGFGWHFDL': {1021},
  'AREFHSGLGWHFDL': {1022},
  'ARGRYDYWSGYLSP': {1392}},
 ('IGHV1-18', 11): {'ARDRGYYAFDI': {1026}},
 ('IGHV3-13', 13): {'VRSDRGVAGLFDS': {1034}},
 ('IGHV3-30', 28): {'ARMFQESGPPRLDRWSGRNYYYYSGMDV': {1035}},
 ('IGHV3-48', 12): {'RLLWFGELFFDY': {1036}},
 ('IGHV1-2', 11): {'AKISGSYSFDY': {1040}, 'AACSNVGCYVY': {28869}},
 ('IGHV3-74', 22): {'ARTGKYYDFWSGYPPGEEYFQD': {1044},
  'ARTGKYYDFWFGYPPGEEYFQD': {19747}},
 ('IGHV1-8', 33): {'LTGSKHRLRDYFLYNEYGPNYEEWGDYLATLDV': {1224}},
 ('IGHV4-31', 10): {'ARLDGYTLDI': {1245}},
 ('IGHV3-64', 16): {'ARDRYYETSGSNAFDV': {1263}, 'ARDIYDVSSAYYGMDV': {202268}},
 ('IGHV3-9', 10): {'ARGGVGSFDT': {1275}, 'ARGGFGSFDT': {1307}},
 ('IGHV3-7', 13): {'ARVSDFGDYGPDF': {1289}},
 ('IGHV1-69', 11): {'ARDTVMGGMDV': {1298}, 'ASRQHHEYFQE': {19708}},
 ('IGHV1-69D', 17): {'ASNRANRADDYDYYFDY': {1339}, 'ARSPSYICSGGTCVFDH': {8695}},
 ('IGHV3-23', 24): {'AKDESPPIYNLMPGYYSTYYYMDV': {1340}},
 ('IGHV3-9', 18): {'VRDAYVSGSDYYYYGLDV': {1343}},
 ('IGHV3-66', 23): {'ARESSYFYDGSYSYYDYEGAMDY': {1346}},
 ('IGHV3-11', 18): {'ARDDGYYDRSGYYGVFDL': {1347}},
 ('IGHV3-33', 13): {'ANAGGGKYDYLDV': {1351},
  'HRNFYDGSGPFDY': {206065},
  'HRNYYDSSGPFDY': {206066}},
 ('IGHV3-23', 18): {'VKDLGIAARRFVSGAFDI': {1354},
  'AKDPGGDSSPAGRTWFDP': {19734}},
 ('IGHV3-53', 15): {'ASRLGVRATTGDLDY': {1355}},
 ('IGHV4-4', 12): {'ARDRDDLSPFDY': {1357}},
 ('IGHV4-4', 15): {'AREEHITFGGVIVRY': {1363}},
 ('IGHV4-39', 11): {'ARERGMHYMDV': {1366}},
 ('IGHV1-18', 21): {'ARDKKQGEVVLPAASFRWFAP': {1373},
  'VRNRVQMEVSPATQSTWYMDL': {1374}},
 ('IGHV3-9', 15): {'ARGRGFHYYYYGMDI': {1381}},
 ('IGHV1-69', 10): {'ARDGRGALQY': {1385}},
 ('IGHV4-59', 20): {'AKPKSRDRGGPGDDYFGMDV': {1388}},
 ('IGHV1-69', 12): {'ARDRPPGAQFDT': {1389}, 'ARDDYSTYAFAY': {1563}},
 ('IGHV3-73', 16): {'IASSTTGWYVREDFDY': {1390}},
 ('IGHV3-30', 20): {'ARDHLGWSSIWSAPESFLDY': {1396}},
 ('IGHV3S1', 7): {'ANWDGDY': {1398}},
 ('IGHV6-1', 16): {'ARGSAMIFGIVIILES': {1400}},
 ('IGHV1-69D', 21): {'ARSSRIYDLNPSLTAYYDMDV': {1403},
  'AREIPGATSGPDHFFFYGMDV': {8701}},
 ('IGHV3-21', 12): {'ARQVGATWAFDI': {1404}},
 ('IGHV4-59', 21): {'ARDFGEYHYDGRGFQCEGFDL': {1409}},
 ('IGHV1-69D', 24): {'ARDFGPDWEDGDSYDGSGRGFFDF': {1458}},
 ('IGHV3-23', 9): {'AKLPFTFDD': {1493},
  'AKDPRKLDY': {1527},
  'ARLAIGDSY': {19770},
  'ARNGTTFDY': {206061}},
 ('IGHV1-69-2', 10): {'AADPWELNNV': {1539}, 'AKESFGIPHF': {19684}},
 ('IGHV6-1', 18): {'ARSGHITVFGVNVDAFDM': {1549}},
 ('IGHV4-31', 15): {'ARGTRLRTLRNAFDI': {1559}},
 ('IGHV1-69', 9): {'ARGSFWFGY': {1561}},
 ('IGHV5-51', 13): {'ARVGRFASHQLDY': {1565}},
 ('IGHV3-13', 16): {'ARDRYSPTGHYYGMDV': {1571}},
 ('IGHV3-30', 12): {'AKGGAAAAVMDV': {1573},
  'ARDGYSSSFFDF': {19728},
  'AKPDRSSSPFAH': {206060}},
 ('IGHV4-34', 20): {'ARAPSGYPGVSLYQYYGLDV': {1580},
  'ARGYADTPVFRRYYYYGMDV': {19613}},
 ('IGHV1-18', 10): {'AREGDGAFDY': {1602}},
 ('IGHV3-30', 10): {'ARDRSYYLDY': {8677}},
 ('IGHV3-21', 10): {'VRGVIDKFDY': {8696}},
 ('IGHV5-51', 16): {'ARLGFEGDYSGSFFDY': {8703}, 'ARLKRRGFSGEGYFDY': {19655}},
 ('IGHV3-15', 15): {'TTGEPLVNHITILDY': {8706}},
 ('IGHV3-33', 15): {'ARGIAGGWAFWGIDL': {8738}, 'ARDLQPPHSPYGMDV': {201248}},
 ('IGHV1-18', 6): {'AAGFHY': {8740}},
 ('IGHV1-69D', 20): {'AKVGGSAYYEDPYSLGYLDF': {8748},
  'AREPDYYDSSGYYPIDAFDI': {19551},
  'ARLDGYSFGHNRYYQDGMDD': {206009}},
 ('IGHV1-18', 23): {'ARVSYYESSGYYYVADYYYGMDV': {8749}},
 ('IGHV3-11', 15): {'ARDRLRNWNDDAFDI': {8750}},
 ('IGHV4-59', 10): {'ARHRNWLFDY': {8783}},
 ('IGHV4-4', 6): {'ARQMRQ': {19543}},
 ('IGHV3-23', 8): {'ARGFGTDF': {19558}, 'AKVHGEAY': {202271}},
 ('IGHV3-73', 10): {'VIRGDVYNRQ': {19574}},
 ('IGHV1-81', 9): {'ARENYGSVY': {19584}},
 ('IGHV3-21', 15): {'ARDRRSGTSPLPLDV': {19591}, 'ARLGYCSGGSCHFDY': {19767}},
 ('IGHV3-13', 21): {'TRGVREVGATGDDPFYYGMYV': {19595},
  'VRGVREVGATGGDPFYYAMAV': {19596}},
 ('IGHV6-1', 17): {'ARDGEISYDYYYYGMDV': {19598}},
 ('IGHV3-13', 18): {'VRGPESGWFYHYYWGLGV': {19609}},
 ('IGHV3-30', 11): {'ARQWGSYAFDS': {19628}},
 ('IGHV3-49', 24): {'AREQRNKDYRYGQEGFGYSYGMDV': {19630}},
 ('IGHV3-15', 24): {'TADLGEPVVSRFFEWGSYYYYMDL': {19634}},
 ('IGHV3-15', 23): {'TMDEGTPVTRFLEWGYFYYYMAV': {19635},
  'TADEGAPILRFFEWGYYNYYMDV': {19637}},
 ('IGHV1-69D', 8): {'AVGLPVDY': {19646}},
 ('IGHV3-7', 17): {'ATLNLELAVDAISEALK': {19685}},
 ('IGHV1-2', 8): {'ARGGWFDY': {19686}},
 ('IGHV3-30', 23): {'AKSGTQYYDTTGYEYRGLEYFGY': {19692}},
 ('IGHV6-1', 10): {'ARGQMGALDV': {19693}},
 ('IGHV3-33', 14): {'ARAAYYDTSGYGDY': {19727},
  'AKLLVGITTDVFDV': {19827},
  'VKVGANWGWRYFDL': {28798},
  'ANDIAGWGYDGSNA': {28849},
  'AIWYLDSPDHGFDI': {28877},
  'TVWYLETPDDGFDI': {28880}},
 ('IGHV4-31', 17): {'AGGSTGDRHYYYYGMDV': {19737}},
 ('IGHV4-39', 12): {'ARLPMVTMSFDY': {19748}, 'AREITMIAWFDP': {200539}},
 ('IGHV1-2', 26): {'AKDLTLMYVFDSGWARGAHDYYGMDV': {19749},
  'ARDLTLMYVHSSGWERGVYYYYGMDV': {19750}},
 ('IGHV5-51', 15): {'ARLSQVSGWSPWVGP': {19766}, 'ARLDARVDAGWQLDS': {19846}},
 ('IGHV4-39', 18): {'ARQRIVSGFVEWLSKFDY': {19771}},
 ('IGHV3-7', 19): {'ARIRQVSKYLQWYPGVFEM': {19772}},
 ('IGHV4-59', 23): {'ARNAIRIYGVVALGEWFHYGMDV': {19773}},
 ('IGHV3-9', 17): {'AIMVATTKNDFHYYKDV': {19779}},
 ('IGHV4-59', 18): {'ARDTYYYDSGDYEDAFDI': {19781},
  'ARDFFEKLIADDLNAFDI': {199390}},
 ('IGHV1-69D', 15): {'ARGIASAGTPDYFFY': {19783}},
 ('IGHV1-2', 10): {'ARLASGFRDY': {19786}},
 ('IGHV2-70', 18): {'ARATNYDSSGYYSLYFDY': {19789}},
 ('IGHV7-4-1', 12): {'ARVYSYGVPFDY': {19801}},
 ('IGHV1-2', 13): {'TRGRDGYDDGFHP': {19806}, 'ARMGAAREWDFQY': {19844}},
 ('IGHV1-2', 21): {'VRDRSNGSGKRFESSNWFLDL': {19807},
  'SRDNFGTRPVPGRGYYYGMDV': {19823}},
 ('IGHV3-49', 9): {'TRGGTLFDY': {19808}},
 ('IGHV3-33', 17): {'ARDRGIGARRGPYYMDV': {19824},
  'ARVQTTTGGGSCCPFDY': {28882}},
 ('IGHV1-8', 14): {'ARGRTGGQPYWFDP': {22513}},
 ('IGKV2-28', 9): {'MQALQTPYT': {26495}},
 ('IGHV3-30-3', 17): {'AKDLSPPYSYAWDIFQY': {26786}},
 ('IGHV1-69D', 11): {'AREGNLNWLDP': {28000}},
 ('IGHV3-33', 11): {'AKSTGDNWFDP': {28867}},
 ('IGHV3-73', 14): {'TRGIIVGDTWHFDP': {28871}},
 ('IGHV3-33', 12): {'TKRAGWGDALDI': {28878}, 'TKRGGWGDGSDI': {28879}},
 ('IGHV1-69', 25): {'ARGWGREQLAPHPSQYYYYYYGMDV': {28881}},
 ('IGHV3-33', 16): {'ARVRDSSDYYGDAFDI': {28883}},
 ('IGHV1-8', 18): {'ATGNADCSGGSCYNWFDP': {36818}},
 ('IGHV1-8', 21): {'ARVRSGTNYGSYYYYYYGMDV': {37271}},
 ('IGHV3-53', 11): {'ARDLGTGLFDY': {201196},
  'ARDWGDYYFDY': {201197},
  'ARDSPHRPGTI': {206008},
  'ARDLVVYGMDV': {206077}},
 ('IGHV4-4', 22): {'ARAPDDYYDSVGYYYGCPYFDS': {201247}},
 ('IGHV1-18', 7): {'ARGKFDY': {202252}},
 ('IGHV2-5', 12): {'ARLTAADTIFDC': {204643}},
 ('IGHV4-30-2', 19): {'ARDRGMVIKRRPWSYGLDV': {206050}},
 ('IGHV3-33', 21): {'ARDLGEYDSLVGPLYTARLGY': {206052}},
 ('IGHV2-5', 14): {'AHRFHSRGWYTFDY': {206053}},
 ('IGHV1-46', 9): {'ARDGNGSDY': {206057}},
 ('IGHV3-48', 27): {'GRVLRDRDVVAGPPARVWDYYYYGMDV': {206058}},
 ('IGHV3-11', 10): {'ARGGDDYADS': {206059}},
 ('IGHV3S53', 14): {'NVKDYGWYNSQYDY': {206698}},
 ('IGHV1-69-2', 22): {'AKPHCSSRTCQRVSGYYFGMDV': {211512}},
 ('IGHV3-64D', 15): {'VKDLYSGRFYYFLDD': {211793}},
 ('IGHV4-61', 16): {'GRVGSRATGLPDWIDP': {211794}},
 ('IGHV3-15', 11): {'LTEQWPRGYDR': {212142}}}

ebola = {('IGHV3-15', 15): {'VRGPFYCDTCGPNDY': {'5T0180'},
  'TTHVPDYNSAYYWVY': {'1T0227'},
  'TTRVDMEWGKYGTDV': {'1T0201'},
  'TTGVVCLDRSSCVGV': {'6664'},
  'TAGVVCLHGSSCVGV': {'6660'}},
 ('IGHV3-15', 8): {'LTPPPRRY': {'3T0265'}, 'TTGGRDMA': {'P7'}},
 ('IGHV3-23', 14): {'AKSVRLSRPSPFDL': {'3T0331'},
  'AKNDDFWGGPTFDY': {'4T0657'},
  'AKDDDFWSGPYFDY': {'5T0257'},
  'AKVVVVTARPYFDY': {'2.1.7E07'},
  'AKDLDNWNYGQFDY': {'5.1.2C07'},
  'AKDFDFWSGNHFDY': {'5.1.5E08'},
  'AKGNDFWSGLNFEY': {'9.6.3E02'},
  'AKESEWLFLSALDY': {'ADI-15767'},
  'MAWGGNYPKDAFDI': {'ADI-15855'},
  'AKEKDFWNGYYIDY': {'ADI-16059'},
  'AKGPMISYYAWFDP': {'66-4-C12'},
  'AKDRVAARLGAFDT': {'56-3-10D'},
  'AKDITVARLYGMDV': {'66-6-3'}},
 ('IGHV3-23D', 14): {'AKSVRLSRPSPFDL': {'3T0331'},
  'AKNDDFWGGPTFDY': {'4T0657'},
  'AKDDDFWSGPYFDY': {'5T0257'},
  'AKVVVVTARPYFDY': {'2.1.7E07'},
  'AKDLDNWNYGQFDY': {'5.1.2C07'},
  'AKDFDFWSGNHFDY': {'5.1.5E08'},
  'AKGNDFWSGLNFEY': {'9.6.3E02'},
  'AKESEWLFLSALDY': {'ADI-15767'},
  'MAWGGNYPKDAFDI': {'ADI-15855'},
  'AKEKDFWNGYYIDY': {'ADI-16059'}},
 ('IGHV4-4', 9): {'LRLSHYGGA': {'4M0368', '4m0368'},
  'ASLTTRPGY': {'2.1.8A01'},
  'AYSNTWTGG': {'5.1.13G03'}},
 ('IGHV1-2', 10): {'GTGIPSDIDY': {'1T0129'},
  'ARGITMICDL': {'5.6.c2647'},
  'ARDDFWSGIT': {'66-6-10'}},
 ('IGHV1-46', 13): {'ARHDSSGYDAFDI': {'1T0130', '2.1.1B02', '66-3-9A'},
  'TCLQLGIADYFDY': {'2.1.1G09'},
  'RRSGWSVTDYFDY': {'ADI-15777', 'ADI-15954', 'ADI-15996'},
  'AIFVLSIGGYQSY': {'ADI-15804'},
  'GRLYSGAPYGLDV': {'1C11'}},
 ('IGHV4-4', 17): {'ARESYRYNAYDIHPFDY': {'1T0139'},
  'TRDAVAASWGFSYGVDV': {'ADI-15853'}},
 ('IGHV1-18', 14): {'ARHVTMILDGWFDP': {'1T0221'},
  'ARDITMVRGGWLDY': {'1T0465'},
  'ARTITMILLGWFDP': {'4T0726'},
  'ARDRGMVYAYMIDY': {'15.0.c889'},
  'ARDLGMVYRYYFDY': {'2.1.1H02'},
  'ARVISMILVGPFDY': {'5.1.1G07'},
  'ARDLGMVGIYYVDY': {'5.1.6D01'},
  'AKVEGEIVATTFDY': {'5.6.1B04'},
  'ARCGGEFIWGWLDP': {'5.6.c3083'},
  'ARDAGMVRPYYFDY': {'9.1.c1965'}},
 ('IGHV4-30-2', 10): {'ARDPGGPFDH': {'1T0225'}},
 ('IGHV3-23', 16): {'AKDKGPRATLGAILDS': {'1T0248'},
  'AKEREVAFVPGAVFNY': {'1T0325'},
  'ARDPRVATTGTVYFDS': {'3T0420'},
  'AKVSDYLWGSHRYFDY': {'4T0541'},
  'AKDAVDTDMVFNWFDS': {'5.1.6H08'},
  'AKDVPEDIVVVEAMDV': {'5.6.1E09'},
  'AKGANFWGAWSDYYPV': {'ADI-15836'},
  'AKDREGRSNVGAICSF': {'66-4-A8'},
  'AKKGGVWGSYAWYFDL': {'66-3-9B'},
  'AKGYCSSTSCPPLFDS': {'ELZ510'}},
 ('IGHV3-23D', 16): {'AKDKGPRATLGAILDS': {'1T0248'},
  'AKEREVAFVPGAVFNY': {'1T0325'},
  'ARDPRVATTGTVYFDS': {'3T0420'},
  'AKVSDYLWGSHRYFDY': {'4T0541'},
  'AKDAVDTDMVFNWFDS': {'5.1.6H08'},
  'AKDVPEDIVVVEAMDV': {'5.6.1E09'},
  'AKDREGRSNVGAICSF': {'66-4-A8'},
  'AKGYCSSTSCPPLFDS': {'ELZ510'}},
 ('IGHV3-23', 17): {'AKDNVRPSGSYSVVLDY': {'1T0264'},
  'AKDVGRFGELLFDWFDP': {'5.1.7A03'},
  'AKDHGNYIWGSPSWFDP': {'5.6.c2494'},
  'AKGSVVVVASTLYYFDY': {'ADI-15850'}},
 ('IGHV3-23D', 17): {'AKDNVRPSGSYSVVLDY': {'1T0264'},
  'AKDVGRFGELLFDWFDP': {'5.1.7A03'},
  'AKGSVVVVASTLYYFDY': {'ADI-15850'}},
 ('IGHV4-34', 13): {'ARSGVLGVYGMDV': {'1T0301'},
  'ARVSLYFGYYMDV': {'ADI-15958'}},
 ('IGHV1-2', 16): {'ATPTMTTRSYYYHMDV': {'1T0321'},
  'ARESMAARRTFYAMDV': {'5.1.1H08'},
  'ARSRFNWNYFPTPIDY': {'ADI-15822'},
  'ARSQYKWNYFPTPIDY': {'ADI-15871', 'ADI-16039'}},
 ('IGHV1-69', 10): {'ATLEMATLFA': {'1T0371'},
  'AVEMATPSDT': {'4T0154'},
  'AGGGTGLFDS': {'4T0525'},
  'AGAVGVATIP': {'2.1.1F11'},
  'ARDLGTPSDY': {'5.1.5E07'}},
 ('IGHV1-3', 14): {'ARGRGTSYYYAFDV': {'1T0451'},
  'ARGGDILTAYTCFF': {'2.1.7D04'}},
 ('IGHV1-8', 19): {'ARGNQWFGELLSSYYGLDV': {'1T0473'},
  'ARGGYFDWLSRWHYYGLDV': {'5.1.13D04'}},
 ('IGHV3-33', 11): {'ARAGAAGAIDV': {'1T0546'}},
 ('IGHV3-23', 13): {'AKFSQLFGYAFDI': {'1T0552'},
  'AKGDDFWSGSPDV': {'4m0333'},
  'AKGNDFWSGYPED': {'2.1.6B10'},
  'ATASVWSGYVLQY': {'5.6.c3363'},
  'AKGYDFWSAYPDY': {'ADI-15751'},
  'AKEMSTYFNGVDV': {'66-6-16'}},
 ('IGHV3-23D', 13): {'AKFSQLFGYAFDI': {'1T0552'},
  'AKGDDFWSGSPDV': {'4m0333'},
  'AKGNDFWSGYPED': {'2.1.6B10'},
  'AKGYDFWSAYPDY': {'ADI-15751'}},
 ('IGHV3-30', 13): {'AIGGSTTVPGLDV': {'1T0565'},
  'ARAYALGLRFMDV': {'2.1.1H08'},
  'AKAHPHSRWFFDS': {'5.6.c4392'}},
 ('IGHV3-30-5', 13): {'AIGGSTTVPGLDV': {'1T0565'},
  'AKAHPHSRWFFDS': {'5.6.c4392'}},
 ('IGHV1-46', 21): {'ARDRQWLPLNGYSYFNYGMDV': {'1T0655'},
  'ARGWWDPEDIVLLPAAPWFDP': {'ADI-15807'},
  'ARDNPGDQWLVPYNSYYYMDV': {'ADI-15921'}},
 ('IGHV1-18', 19): {'ARGLGDSYSNAWFVYVFDY': {'3T0123'},
  'ARARQLLRDLLFAPQGMDV': {'ADI-15763'},
  'ARGAVLIWFGEPGGHGLDL': {'ADI-15797'},
  'ARDRLLFYHILTASYPFDY': {'ADI-15834'},
  'ARCSELYYDILTSSYFFDY': {'ADI-16007'}},
 ('IGHV3-13', 12): {'ARAAFGAVFFDY': {'3T0202'},
  'ARAAFGAVYYDN': {'3T0468'},
  'ARARFGDLALDY': {'4T0444'},
  'ARASFGDLYFDL': {'4T0578'},
  'ARVRFGDTAVDY': {'5.1.10B03'},
  'ARAAFGSHYFDY': {'5.1.7D03'},
  'ARSFGFLYGFDV': {'5.6.c3105'},
  'ARARFGDNVFDL': {'9.6.1A09'},
  'ARAVFGSSAFDI': {'ADI-16029'}},
 ('IGHV3-48', 15): {'ARDTLEAGSWYPFDK': {'3T0215'},
  'ARDAVTTFYYYGMDV': {'5.1.5H03'},
  'ARDPQGEWLPYGMDV': {'5.1.6D10'},
  'ARVMTTSFYYYGVDV': {'5.6.c4395'},
  'AREYGYSGSSRAFDI': {'EV035-2-A10'}},
 ('IGHV3-15', 11): {'ATRVHYNGMDV': {'3T0245'},
  'YTLRFFGPGNS': {'5T0278'},
  'TTVYRYNYDSV': {'2.1.1D05'},
  'TTDSPYSYTFP': {'ADI-15765'},
  'TTRIVLNGMDV': {'6662'},
  'TTRWVYNGMDV': {'6666'},
  'TTYTEDMQYFD': {'EP3583122_26_PE-47'},
  'STRVKYNGMDV': {'EV035-1-A2', 'EV035-2-C7'}},
 ('IGHV3-15', 10): {'TTRHHRGMDV': {'3T0253'},
  'TTGHITGTLF': {'3T0411'},
  'VATPHSWSVA': {'3T0650'},
  'ATEPRGYDWG': {'4T0452'},
  'ATDYYESRGY': {'5T0209'},
  'TTYREEGLDY': {'18-1-D3'},
  'TTRVSAPFDI': {'6670'}},
 ('IGHV1-18', 12): {'AWRRSSWFAFDV': {'3T0258'},
  'ARDLTPRYGMDV': {'ADI-15772', 'ADI-15780'},
  'ARDLTPRDGMDV': {'ADI-15784'},
  'ARDLTPRYGLDV': {'ADI-15935'}},
 ('IGHV3-15', 16): {'TTLNLGGGFPGEWRSV': {'3T0338'},
  'TTDLWQPGSYYYYMDV': {'ADI-16001'}},
 ('IGHV3-23', 15): {'AKDLKGNWNDGPFDY': {'3T0350'},
  'AKDHRVWAPGYYFDH': {'ADI-15742', 'EP3583122_22_PE-24'},
  'AKSGTVNYYFYYMDV': {'ADI-15847'},
  'AKDHRVWAAGYHFDY': {'ADI-15878', 'EP3583122_16_PE-87'},
  'AKDQDFWSGYSPPIT': {'ADI-15970'},
  'AKDRDFWSGSRDFDY': {'ADI-15986'},
  'AKDYDFWSGSRHFDY': {'66-6-20'},
  'ANISDWLLVWRYFDF': {'6544'},
  'AKDLGSGSYAALFDY': {'66-6-12'}},
 ('IGHV3-23D', 15): {'AKDLKGNWNDGPFDY': {'3T0350'},
  'AKDYDFWSGSRHFDY': {'66-6-20'}},
 ('IGHV1-2', 6): {'AAGLGH': {'3T0368'}},
 ('IGHV3-30', 10): {'AANYRDSELE': {'3T0405'}},
 ('IGHV3-30-5', 10): {'AANYRDSELE': {'3T0405'}},
 ('IGHV3-23', 6): {'AINGGV': {'3T0415'}},
 ('IGHV3-23D', 6): {'AINGGV': {'3T0415'}},
 ('IGHV3-64D', 13): {'TKDHHWSGQYTDY': {'3T0427'}},
 ('IGHV4-59', 17): {'ARDKRYYDSSGYSHFDY': {'3T0478'},
  'ARVTTSSFSSYYYGMDV': {'5.1.5D07'},
  'ARAAKGCTSTSCYEWDV': {'ADI-15877'},
  'ATSKTISGVVATYYFDD': {'ADI-15888'}},
 ('IGHV3-33', 20): {'ARGGDLLVEVDSTDYYGLDV': {'3T0553'},
  'VRGGDLLLLPDSIDYYGMDV': {'4T0784'},
  'ARDVRDGDDIFSGYHYGMDV': {'5.6.c3027'},
  'AREPGFCSGGTCFQADYFDY': {'ADI-15832'},
  'AKEGFLEWLSPSDYYFGMDV': {'ADI-15896'},
  'ARVGSYGSGPLLYSFYYMDV': {'ADI-15919'},
  'ARGGDIVVPAGSMDYYGMDV': {'ADI-16015'},
  'ARGGSRGLEMATIYGGGLIY': {'ADI-16021'},
  'AREDSGYDSGGRGFYYGLDV': {'EV035-2-C11'}},
 ('IGHV3-48', 14): {'AGILDDYRDYGYDY': {'3T0611'},
  'ARVQDDILTGYYDY': {'5.1.8A11'},
  'ATTSDDFWSGYYDY': {'5.6.1F04'},
  'AANHGDNLFWYFDL': {'5.6.c3113'}},
 ('IGHV3-15', 14): {'TTYYYDNGGSYSNP': {'3T0673'},
  'TRGPYDNFSGWRDY': {'5T0451'},
  'TTNGYDSSGYYSSL': {'ADI-15824'},
  'TTRYSSRWSGVSDY': {'EV058-1-A11',
   'EV058-1-A4',
   'EV058-1-A8',
   'EV058-1-B12',
   'EV058-1-B5'}},
 ('IGHV4-39', 11): {'ARVTMKNFFDS': {'4m0361'}},
 ('IGHV3-11', 15): {'ARGERRHQVLSGMDV': {'4m0373'}},
 ('IGHV1-2', 14): {'ARLTVVTAISAFDI': {'4m0387'},
  'ARLTVAPIIGAFDI': {'2.6.2A09'},
  'ARDPTYISGGWRDY': {'EBOV-1164'}},
 ('IGHV3-9', 17): {'AREGRDGYNLPYYAMDV': {'4T0115'}},
 ('IGHV4-39', 6): {'ARRFDS': {'4T0159'},
  'VRRFDY': {'4T0176'},
  'ARRFDY': {'5T0378'},
  'ARRFDL': {'5T0420'},
  'ARRMDV': {'2.1.1A04'}},
 ('IGHV3-30', 12): {'AKGGATAAVFDS': {'4T0168'}},
 ('IGHV3-30-5', 12): {'AKGGATAAVFDS': {'4T0168'}},
 ('IGHV1-2', 20): {'AAPGETIVRGVIYHYYGMGV': {'4T0182'},
  'ARAEVLGLVEQLMEFNWFDP': {'ADI-15739'},
  'AKAWPTDIVILPDALSGFDA': {'ADI-15889'},
  'ARGPITNYVVINAYDYYMDV': {'ADI-15987'},
  'ARAWPTDIVILPTALTGLDP': {'ADI-16030'}},
 ('IGHV4-59', 19): {'ARAPRGYSSGKYNYYGLDV': {'4T0243'},
  'ARAPRGYSSGWYYYYGMDV': {'5T0465'},
  'ARVRRWIELGTGLGDWFDP': {'5.6.c2712'},
  'VRHYSDFWSGYHTPIWFDP': {'ADI-15944'},
  'ARYYYDSRGYYSHYYHMDV': {'ADI-15982'},
  'ARASITGFGVLIMEGVFDS': {'ADI-15988'},
  'VRASRSYYWGSYRPTAFDS': {'mAb100'}},
 ('IGHV1-46', 14): {'ARGITMIRDGWFDH': {'4T0262'},
  'TRRGIDRSGYYCDY': {'ADI-15810'}},
 ('IGHV1-18', 15): {'ARGITMVRGLDWFDP': {'4T0284'},
  'ARAREMVRGVTLIDY': {'5.1.7B04'},
  'ARDMGMVQEANWFDP': {'5.1.8B08'},
  'ARDPGMITPGGVIEH': {'5.6.c2644'},
  'ARSRYGDFWSGYCDY': {'56-3-3D'}},
 ('IGHV6-1', 19): {'VREYYDLWNGFYPGGAMDV': {'4T0306'}},
 ('IGHV3-23', 18): {'VKGSWPRTTVLSTYYFDY': {'4T0344'},
  'AKVGEYYDFWSGYSPFDY': {'2.1.1B04'},
  'AKVGEYYDFWSGYSPFEY': {'2.1.1D07'},
  'AKVGEYYDFWSGYSPFDS': {'2.1.7G07'},
  'AKCGEYYDFWSGYSPFDY': {'5.1.9E03'},
  'AKDSEVFGVLILPRGMDV': {'ADI-16036'},
  'VKPQGYYDSSGYSRAFDI': {'66-6-15'}},
 ('IGHV3-23D', 18): {'VKGSWPRTTVLSTYYFDY': {'4T0344'},
  'AKVGEYYDFWSGYSPFDY': {'2.1.1B04'},
  'AKVGEYYDFWSGYSPFEY': {'2.1.1D07'},
  'AKVGEYYDFWSGYSPFDS': {'2.1.7G07'},
  'AKCGEYYDFWSGYSPFDY': {'5.1.9E03'},
  'AKDSEVFGVLILPRGMDV': {'ADI-16036'},
  'VKPQGYYDSSGYSRAFDI': {'66-6-15'}},
 ('IGHV3-72', 6): {'VRTMDV': {'4T0350'}},
 ('IGHV4-39', 14): {'ATSSRGSVSYYSRY': {'4T0365'},
  'ASGYGEFLYNWFDP': {'5.1.5D10'},
  'ARQAPPGWYYGMDV': {'5.1.7A02'},
  'ASLWGWNDVGWFDS': {'5.6.c3387'},
  'ARHRALLVVAYFDY': {'ADI-15865'}},
 ('IGHV3-33', 19): {'VRETFQPGGEVPPLWYFDV': {'4T0412'},
  'ARDGSITSSWNLYYYGMDV': {'5.6.1E04'},
  'ARDGCSSTDCLLYYYAMDV': {'5.6.c4515'},
  'AREGFCSEGICTLGYQLDY': {'ADI-15948'},
  'ARRYFDWLLTPIDYYGLGV': {'6656'}},
 ('IGHV3-9', 16): {'AKENRIELLPGWGMDV': {'4T0423'},
  'ARESRGAVVTSFAFDI': {'2.1.1C11'},
  'AKDIGNYEFWSGYFDY': {'6668'}},
 ('IGHV3-53', 15): {'ARDEEWLFSGYGMDV': {'4T0427'},
  'ARETVFGSQYYGMDV': {'ADI-15886'}},
 ('IGHV4-34', 10): {'ARHGHTGMDV': {'4T0429'},
  'ARHGHNGMGV': {'2.1.6F02'},
  'ARHAHSGMDV': {'ADI-15943'},
  'ARGETVRLDP': {'ADI-16050'}},
 ('IGHV3-74', 14): {'ARDVGLYNTGWIDY': {'4T0434'},
  'ARVAYGDYWRWFDP': {'2.1.6B07'}},
 ('IGHV3-33', 14): {'ARQATISDFYYLDS': {'4T0520'},
  'ARDPGGIVGAQFDY': {'5.1.10C12'},
  'ARGRGSSGWYFLDY': {'5.1.2C03'},
  'ARDRGGIVGSEFDY': {'5.1.5H01'},
  'ARVPPWGLNGGMDV': {'5.1.7F06'},
  'AREYCSGGTCYLDY': {'121'}},
 ('IGHV1-46', 17): {'ARALPFRVTGARDVFDI': {'4T0570'},
  'ARDRFPTVSGEPFAMDV': {'5.6.c2618'},
  'ARDRYPVLVATDYGMDV': {'ADI-15848'},
  'ALLAGYSGFYYLVPFDY': {'ADI-15927'},
  'ARDRYPVLFATDYGMDV': {'ADI-16061', 'EP3583122_30_PE-16'}},
 ('IGHV4-59', 10): {'ARGLLGSQDS': {'4T0764'}, 'ARGLLGPGDS': {'5T0376'}},
 ('IGHV3-15', 13): {'TTSLNIWGTYRDC': {'5T0202'},
  'MTGFEHTYSYFDL': {'5T0337'},
  'TADSIAGLPAAIE': {'ADI-15934'},
  'VTPPVGPHQYYVY': {'ADI-16046'},
  'IPPPMVRGVTLDY': {'45-4-A5'},
  'TTNFWSGRDYMDV': {'105'},
  'TTHYSDSSGYVDY': {'EV035-2-A7'}},
 ('IGHV3-15', 9): {'TKGGPGAHS': {'5T0223'},
  'TTDSPRVGI': {'ADI-15814'},
  'TTQRGVTDY': {'132'},
  'NTVRSGADY': {'6667'},
  'MTRRSGWDS': {'6665'}},
 ('IGHV4-59', 21): {'ARMSRYFDWLSQQWSFPLVLD': {'5T0377'},
  'ARDPRYYDYFRGSYGHYGLDV': {'ADI-15860'},
  'ARLLWGSMRFLEWSPSGYFDS': {'ADI-15973'},
  'ARDERLLVEVGTDHFYYGLDV': {'BDBV407'}},
 ('IGHV1-69', 18): {'ARLYCSSSSCSIYNYMDV': {'5T0404'},
  'ARDDRDYYDSNGYYLFDH': {'5.1.10B07'},
  'ARDWLHSRSPRAGNWFDP': {'66-3-7B'},
  'AREDTGVAWAPYYYGMDV': {'56-3-11D'},
  'ARDAPIILVEGPETGMDV': {'BDBV343'}},
 ('IGHV1-69', 19): {'ARFRFFQGGGSFYYYGLDL': {'5T0406'},
  'ARDPPPGYGDLFYYYSMDV': {'5.6.c2866'},
  'AGPARTCSGGSCYSRGFDY': {'EV120-2-B1'}},
 ('IGHV1-69D', 19): {'ARFRFFQGGGSFYYYGLDL': {'5T0406'},
  'AGPARTCSGGSCYSRGFDY': {'EV120-2-B1'}},
 ('IGHV4-59', 18): {'ARGAWNVATVYYYYGMDV': {'rEBOV-520'},
  'ARGLWFGELIYYYYGMDV': {'2.1.1D03'},
  'ARVKPPYSSIRLHYGMDV': {'5.1.5C02'}},
 ('IGHV3-30', 24): {'AKELLQVYTSAWGEGHSYYYALDV': {'rEBOV-548'}},
 ('IGHV1-2', 15): {'ARDSGELLFVGSDV ': {'rEBOV-434'}},
 ('IGHV1-69', 27): {'ARGPPLRGERSWFGESEKYDYFYMDV ': {'rEBOV-437'}},
 ('IGHV3-15', 25): {'ATGSGKGPSASFGESYYYYDFINV ': {'rEBOV-442'}},
 ('IGHV1-2', 11): {'ARGRRHGAYVD': {'rEBOV-446'}, 'AVGFDSNGWSN': {'116'}},
 ('IGHV3-20', 14): {'VSWGERYDAYFDY ': {'rEBOV-451'}},
 ('IGHV3-23', 22): {'AKDAQQETDIVYFYYYDGMDV ': {'rEBOV-502'},
  'AKEGSPLSDVLLVAAPFGWFDP': {'9.6.3D06'},
  'ARGGEMATSSWGYGYYYYYMDV': {'ADI-15746'},
  'AKVGMTAVTKGMEIDYSYGMDV': {'ADI-15768'},
  'ARLQRFSFTMGVVVITEPAFDL': {'ADI-16043'}},
 ('IGHV1-2', 12): {'WIWFRSETFDF ': {'rEBOV-507'},
  'ECCRRYDVLI*L': {'EV063-3-C10'}},
 ('IGHV1-46', 10): {'VSFQFYFDY ': {'rEBOV-508'}},
 ('IGHV4-30-4', 20): {'ARESDGDPSRLYFYFAMDV ': {'rEBOV-510'}},
 ('IGHV4-39', 20): {'ARHLAPISGVIFIPSFFDS ': {'rEBOV-511'},
  'ARQITRDLEGLLWLPDAFDI': {'5.1.5C06'},
  'ARSFRGPTGAFYYYSYAMDV': {'5.6.c3362'},
  'ARGVRREFSNILTSYSHFAY': {'ADI-15806'},
  'ARRVVVVVAGILLESDYFDY': {'ADI-15891'},
  'ARSFMITFGGVLVEHDAFDI': {'ADI-15894'}},
 ('IGHV4-30-4', 19): {'ARDKAQAYGLLYHYHTDV ': {'rEBOV-514'}},
 ('IGHV4-31', 15): {'ARESSWVSELGRDN ': {'rEBOV-515'},
  'ARGHSGDYSPPFFDY': {'ADI-15881'}},
 ('IGHV3-7', 19): {'ARGASIEVEILYYYHMDV ': {'rEBOV-517'},
  'ARDLGTTDALLWFGELFDY': {'2.1.1A07'},
  'ARSPPEEPGALFFRHYFDD': {'5.1.7E04'},
  'AKATVTTELTFFYYYALDV': {'5.6.c2685'},
  'AREAFLEWLAPLGHYYMDV': {'ADI-15880', 'ADI-15964'},
  'AREAFLEWLAPLGYYYMDV': {'ADI-15910'},
  'ASPGAIHSSDWYYYLAMDV': {'6653'}},
 ('IGHV2-5', 14): {'AHSGGLVAGAFDY ': {'rEBOV-518'}},
 ('IGHV3-30', 22): {'AKDVLDCSRADCFIYYYYMDV ': {'rEBOV-524'},
  'AKDLYYCSGGSCLYYYYYGMDV': {'5.1.6B03'},
  'ANQLICVNGVCYKTTSVAGIDY': {'5.6.c2693'},
  'ARSEYSSLPRCSSSQEAMLLNS': {'EV063-3-D9'},
  'AKDLPPLLVPAAISYYYCGMDV': {'EV120-1-C11'}},
 ('IGHV3-30-5', 22): {'AKDVLDCSRADCFIYYYYMDV ': {'rEBOV-524'},
  'AKDLYYCSGGSCLYYYYYGMDV': {'5.1.6B03'},
  'ANQLICVNGVCYKTTSVAGIDY': {'5.6.c2693'},
  'AKDLPPLLVPAAISYYYCGMDV': {'EV120-1-C11'}},
 ('IGHV1-69', 14): {'ARDTASFGWLPFAF': {'EBOV-293', 'rEBOV-237'},
  'TREGRGAVAGAADY': {'5.1.7B10'},
  'ARESEGSGWNPFDY': {'ADI-15766'},
  'ARDNSGYDLNPLHY': {'ADI-15794'}},
 ('IGHV3-30', 21): {'AKDYYYGSGSDLYYYYYGMDV': {'15.0.c770'},
  'AKGARSSSSLDLYYYYYYMDV': {'15.0.c888'},
  'AKDRRYSSSSELFYYYYGMDV': {'2.1.1C12'},
  'AKDLSEQFGMLDLYYYYGLDV': {'2.1.1F09'},
  'AKDEEYSSSSDLFYYYSGMDV': {'5.1.5A06'},
  'AKDLEYSSSSDLFYYYNAMDV': {'5.1.5B09'},
  'AKDLHRGDFGDLFYYYYGLDV': {'5.1.5G12'},
  'AKDMEYSSGSDLFYYYYGMDV': {'5.1.5H05'},
  'AKDFSTSSSHDFLYYYYGMDV': {'5.1.6E08'},
  'AKDGYIAVAGDLFYYYYGMDV': {'5.1.7A10'},
  'AKDLYGSSSGDLFYYYDGMDV': {'5.1.7C01'},
  'AKDFDDSSGSDLIYYHYGMDV': {'5.1.7C08'},
  'AKDLGFGESGDLFYYYSAMDV': {'5.6.2B02'},
  'ARENYGDDTLILVGSYYGMDV': {'ADI-15907'},
  'AREHLDFRSGYASWLVGDFVY': {'6536'},
  'ARDRAIAALGDLLYYYYGMDV': {'6533'}},
 ('IGHV3-30-5', 21): {'AKDYYYGSGSDLYYYYYGMDV': {'15.0.c770'},
  'AKGARSSSSLDLYYYYYYMDV': {'15.0.c888'},
  'AKDRRYSSSSELFYYYYGMDV': {'2.1.1C12'},
  'AKDLSEQFGMLDLYYYYGLDV': {'2.1.1F09'},
  'AKDEEYSSSSDLFYYYSGMDV': {'5.1.5A06'},
  'AKDLEYSSSSDLFYYYNAMDV': {'5.1.5B09'},
  'AKDLHRGDFGDLFYYYYGLDV': {'5.1.5G12'},
  'AKDMEYSSGSDLFYYYYGMDV': {'5.1.5H05'},
  'AKDFSTSSSHDFLYYYYGMDV': {'5.1.6E08'},
  'AKDGYIAVAGDLFYYYYGMDV': {'5.1.7A10'},
  'AKDLYGSSSGDLFYYYDGMDV': {'5.1.7C01'},
  'AKDFDDSSGSDLIYYHYGMDV': {'5.1.7C08'},
  'AKDLGFGESGDLFYYYSAMDV': {'5.6.2B02'}},
 ('IGHV3-23', 20): {'AGDSSGYNNERLYYTYYMDV': {'15.0.c775'},
  'AGDSSGYNNERMYYTYYMDV': {'15.0.c800'},
  'ATDSSGYNYERLYYTYYMDV': {'15.0.c830'},
  'ARRVLVWFGELLYRGGYFDY': {'2.1.6B06'},
  'AKQTATIFGAEDFFYYGMDV': {'5.1.5G10'},
  'AKDAGSEVEPTGILYNWFDP': {'5.1.7E05'},
  'AKNIGVLAVIYSAEDDAFDM': {'ADI-15823'},
  'ARSSELSGSYYLQAFDYFDY': {'ADI-15957'},
  'AAERLQWFDYLSSTDYYMDV': {'ADI-16010'},
  'ANSYYYHSSGLLIRWDDMDV': {'40'}},
 ('IGHV3-23D', 20): {'AGDSSGYNNERLYYTYYMDV': {'15.0.c775'},
  'AGDSSGYNNERMYYTYYMDV': {'15.0.c800'},
  'ATDSSGYNYERLYYTYYMDV': {'15.0.c830'},
  'ARRVLVWFGELLYRGGYFDY': {'2.1.6B06'},
  'AKQTATIFGAEDFFYYGMDV': {'5.1.5G10'},
  'AKNIGVLAVIYSAEDDAFDM': {'ADI-15823'}},
 ('IGHV4-4', 21): {'ARDFVVIDPTRVVDDYDAFDV': {'15.0.c778'},
  'ARQVVLLGFGDLLYRNTCFDP': {'ADI-15815'},
  'ARDGGGSNSSGFRVFRATFDY': {'ADI-16003'}},
 ('IGHV3-15', 21): {'TADVLPAATRGVYYYYYYMDV': {'15.0.c779'},
  'TADVIPAATRGVYYYYYYMDV': {'15.0.c780', '15.0.c859'},
  'ITENYDFWSAYYRHYYYGMDV': {'ADI-15795'},
  'STDQLLTHSDFMTGYYRGFDY': {'ADI-15830'}},
 ('IGHV3-48', 17): {'ARESPTYYDFWSGYSDY': {'15.0.c792'},
  'ARDQLWFGESPLYYFDY': {'2.1.1F04'},
  'ARASLWFGEHPAYYFDY': {'5.1.5B08'},
  'ARFSDGSGSIYYYGMDV': {'5.1.5C04'},
  'AREGPTPMDYYYYYMDV': {'ADI-15858', 'ADI-16053'},
  'VREGPTHYDIFYYYMDV': {'ADI-15882'},
  'AREGPSPSDSYYYYMDV': {'ADI-15895'}},
 ('IGHV3-30-3', 19): {'ARDLLWFGELLFREYYMDV': {'15.0.c819'},
  'ATDGPLNNWNGDPAGCFDY': {'5.6.2D06'}},
 ('IGHV3-15', 19): {'TTGSDFWSGSFYYYYYMDV': {'15.0.c835'},
  'TADCVLLWFGDLLYCGMDV': {'19-2-12C'}},
 ('IGHV3-7', 18): {'ARTRDSSSSFYYYYYMDV': {'15.0.c846'},
  'ARDKGGETIFGVVMTLDY': {'5.1.5F08'},
  'ARFYARHYDILYPWDFDY': {'5.1.6C09'},
  'ARDGGYSSDWYFLEYFQH': {'5.1.7D05'},
  'ARSKTYYYDSSGYYWFDY': {'ADI-15911'}},
 ('IGHV3-20', 15): {'ARHRYDSSGQWYFDY': {'15.0.c865'},
  'AVHYYDSSGIYYLDD': {'15.0.c942'}},
 ('IGHV1-18', 20): {'ARVDESHDFWSGYYYYGMDV': {'15.0.c896'},
  'ARERVELRSSLFFYYFGMDV': {'2.1.1B10'},
  'ARDLITFGGEIVPRGGGFDI': {'5.1.6H04'},
  'AREYSVVPAALRGPLNAFDV': {'9.6.3A11'},
  'ARDGFSDIGMVEFYYYGMDV': {'ADI-15756'},
  'ARDGQTFYDILTTQWYGMDV': {'ADI-15826'},
  'ARVGGGFGELLYLGVASHDY': {'ADI-15890'},
  'ARSVLRYSDWLLYDADYMDV': {'ADI-16027'}},
 ('IGHV4-31', 17): {'ARDRGDPGGYYNYGMDV': {'15.0.c912'},
  'ARDSGSEIIMGAYGMDV': {'5.6.c2886'},
  'ARGLLWFGESPFYYFDY': {'5.6.c3206'}},
 ('IGHV3-23', 21): {'AKDHGIPVDGIVYHYYYGLDV': {'2.1.1A02'},
  'AKEHYYNILTGYLRAHNWFDP': {'ADI-15774'},
  'AKDLRSWDIVVVPAVHGAFDI': {'ADI-15828'},
  'AKDALTVTTVLWGSDQYYFDY': {'ADI-15837'},
  'AKVEGEWSDIVVVVAATPFDY': {'ADI-15939'},
  'AKDSLWLGDLLGGDFYYGMDV': {'6663'}},
 ('IGHV3-23D', 21): {'AKDHGIPVDGIVYHYYYGLDV': {'2.1.1A02'},
  'AKDLRSWDIVVVPAVHGAFDI': {'ADI-15828'}},
 ('IGHV3-30', 19): {'ANLFIAARQKNYFFYGMDV': {'2.1.1A03'},
  'AAPDPYITSSSHYYNGMDV': {'2.6.2A05'},
  'AKDSPGEQWLILSYYGMDV': {'ADI-16011'},
  'ATRRFRELLERYDYYGLDV': {'ADI-16045'},
  'AKRGGHDYGYYDNNRYIDL': {'BDBV392'}},
 ('IGHV3-30-5', 19): {'ANLFIAARQKNYFFYGMDV': {'2.1.1A03'},
  'AAPDPYITSSSHYYNGMDV': {'2.6.2A05'},
  'AKDSPGEQWLILSYYGMDV': {'ADI-16011'},
  'ATRRFRELLERYDYYGLDV': {'ADI-16045'}},
 ('IGHV4-30-2', 16): {'ARGVETAVIGYWYFDL': {'2.1.1A08'}},
 ('IGHV3-43', 16): {'AKDRLGGAFWSGNFDY': {'2.1.1B03'},
  'AKDVALGEFWSGYYPA': {'5.1.5D08'},
  'ARDLHNYAFWSGYPDY': {'5.6.c2518'},
  'ARDTAGGAFWSGYPDY': {'5.6.c3567'},
  'AKDILGGEFWSGSCSG': {'6654'}},
 ('IGHV3-30', 17): {'AKDLPRYDDFWSGYCDY': {'2.1.1B06'},
  'AKEGATVTDLYYYGMDV': {'5.1.5A04'},
  'AKEGASVTALYYYGMDV': {'5.1.6D07'},
  'AKEANLYYDILTTHFDY': {'5.1.7A07'},
  'AKDLVGIEGLYYNGMDV': {'5.1.7B11'},
  'AKDLASYYDFWIGYFDY': {'5.1.7D11'},
  'AKDRPLYNDFWSGYYDD': {'5.1.7E01'},
  'ARDVETSTALYYSGMDV': {'5.6.1C03'},
  'AKSIILMTALFEDAFDM': {'5.6.1C04'},
  'AKNRLVFGVIWFYDMDV': {'5.6.c2455'},
  'AKDFEVFSSIFNGAYDS': {'5.6.c2682'},
  'AKEGAGHDALYYYGMDV': {'5.6.c3197'},
  'ARDWPLWNDFWSGYLAY': {'6545'},
  'AKDRYCDAGTCSGSLDY': {'5T0107'}},
 ('IGHV3-30-5', 17): {'AKDLPRYDDFWSGYCDY': {'2.1.1B06'},
  'AKEGATVTDLYYYGMDV': {'5.1.5A04'},
  'AKEGASVTALYYYGMDV': {'5.1.6D07'},
  'AKEANLYYDILTTHFDY': {'5.1.7A07'},
  'AKDLVGIEGLYYNGMDV': {'5.1.7B11'},
  'AKDLASYYDFWIGYFDY': {'5.1.7D11'},
  'AKDRPLYNDFWSGYYDD': {'5.1.7E01'},
  'AKSIILMTALFEDAFDM': {'5.6.1C04'},
  'AKNRLVFGVIWFYDMDV': {'5.6.c2455'},
  'AKDFEVFSSIFNGAYDS': {'5.6.c2682'},
  'AKEGAGHDALYYYGMDV': {'5.6.c3197'}},
 ('IGHV1-8', 14): {'APRKGSYYSGWFDP': {'2.1.1B09'}},
 ('IGHV3-23', 19): {'AKNNLWLHLGESLSYWFDP': {'2.1.1C06'},
  'AKPKEGSEWLILRFDAFDV': {'ADI-15827'}},
 ('IGHV3-23D', 19): {'AKNNLWLHLGESLSYWFDP': {'2.1.1C06'}},
 ('IGHV3-9', 12): {'AKLDLAAEYFQH': {'2.1.1E06'}},
 ('IGHV3-30-3', 21): {'ARDLGIAAASDLLYYYHGMDV': {'2.1.1E09'},
  'ARDLEYSSSSDLYYYYYGMDV': {'5.1.5E10'},
  'ARDRIRYSDWGVYYYYNGMDV': {'5.6.c2526'}},
 ('IGHV3-21', 25): {'ARVGQGYCISTGCYEWDYYNNVMDV': {'2.1.1F05'}},
 ('IGHV1-18', 17): {'ARDRADMTSLLFDAFDI': {'2.1.1F06'},
  'ARDSDMVTALFYYGMDV': {'5.1.5D03'},
  'ARDLDVMVLATNVRFDY': {'5.1.6E03'},
  'ARDLGELSSLKFYGMDV': {'5.6.c3013'},
  'AKDSSAYWDLLFYGMDV': {'5.6.c3169'},
  'ARDSGDLSSLLYYGMDV': {'5.6.c3508'},
  'ARGGAVTDLYFSYVMDV': {'5.6.c4471'},
  'ARVAPPLMILADLGLDP': {'ADI-15760'}},
 ('IGHV3-7', 16): {'ARVAAEDDFWSGFFDY': {'2.1.1F07'},
  'VRDCEMSVVLSDAFDI': {'5.1.5B06'},
  'ARDVEAVAVVPSPFDY': {'5.1.6B04'},
  'ARDISAYDLVFWYFDY': {'5.1.7C09'},
  'ARETYYDSILTDAFDI': {'5.1.7D02'},
  'AREDPYDDFWNGYYAY': {'5.1.7F05'},
  'ARDLEMATIMGGPFDY': {'5.1.8E07'},
  'ARDVPGDTVLGDAFHI': {'5.6.c2801'}},
 ('IGHV3-23', 26): {'AKDREPGEEETYYDILTGYPRGASDI': {'2.1.1F12'}},
 ('IGHV3-23D', 26): {'AKDREPGEEETYYDILTGYPRGASDI': {'2.1.1F12'}},
 ('IGHV3-33', 21): {'ARGGYYDSSGYYWDYNYGLDV': {'2.1.1H05'},
  'ARDLRPSTNSWYGYYYNAMDV': {'5.6.c2995'},
  'ARDASLTSFWSGFYYYYYMDV': {'9.6.3C09'},
  'AKDLLYGSGMVPNYYYYGLDV': {'BDBV377'}},
 ('IGHV3-30-3', 13): {'ARAYALGLRFMDV': {'2.1.1H08'},
  'ARDFWLLLDAFDI': {'ADI-15904'}},
 ('IGHV3-30', 15): {'AKDQQQLVLGPGFDP': {'2.1.1H12'},
  'TQDRYPKAVMRYFPT': {'5.6.1A12'},
  'AKDTISVAIYGHFDT': {'5.6.c3023'},
  'AKGGVLIAIINYFDY': {'ADI-15732', 'ADI-15819'},
  'AKGTVIIAMLNYFDY': {'ADI-15785'},
  'AKGRAPVAGTSYFDY': {'ADI-15811'},
  'AKGAVVIAMLNYFDY': {'ADI-15841', 'ADI-15916'},
  'AKGAVVIAMLNYFDS': {'ADI-15925'}},
 ('IGHV3-30-5', 15): {'AKDQQQLVLGPGFDP': {'2.1.1H12'},
  'TQDRYPKAVMRYFPT': {'5.6.1A12'},
  'AKDTISVAIYGHFDT': {'5.6.c3023'},
  'AKGGVLIAIINYFDY': {'ADI-15732', 'ADI-15819'},
  'AKGTVIIAMLNYFDY': {'ADI-15785'},
  'AKGRAPVAGTSYFDY': {'ADI-15811'},
  'AKGAVVIAMLNYFDY': {'ADI-15841', 'ADI-15916'},
  'AKGAVVIAMLNYFDS': {'ADI-15925'}},
 ('IGHV3-23', 10): {'AIISPLQFDY': {'2.1.6A07'}},
 ('IGHV3-23D', 10): {'AIISPLQFDY': {'2.1.6A07'}},
 ('IGHV3-53', 10): {'ARGSIAAGDY': {'2.1.6B11'}},
 ('IGHV4-34', 20): {'ARDSTHTVLVPAEGAFGMDV': {'2.1.6C02'},
  'ARGRGGDIVIPHDAVGGMDV': {'ADI-16026'}},
 ('IGHV1-8', 6): {'APGVTF': {'2.1.6C11'}},
 ('IGHV3-21', 20): {'ARVPREILWFGELRYYGMDV': {'2.1.6E01'},
  'ARALPSMVRGVIYYYYGMDV': {'66-3-2B'}},
 ('IGHV4-34', 21): {'ARGRNREILVLTTTPYNGLDV': {'2.1.7B08'},
  'ARGSGTYYYDSGGYYRDAYDI': {'ADI-15844'},
  'ARGAGIIFGGVVLTNNNWGDV': {'ADI-15938'},
  'ARGRVGPEILVPAAAGHYMDV': {'ADI-15985'}},
 ('IGHV4-59', 14): {'ASAYDDYVFDAFDI': {'2.1.7D10'},
  'ARSVVVIENDAFDI': {'5.6.c4011'},
  'ARDWITIFGRYFDV': {'BDBV231'}},
 ('IGHV1-3', 20): {'ARDGTEVRSQLLFGLDWFDP': {'2.1.7F02'},
  'ARETSKYDILTGPHDYYMDV': {'ADI-15764'},
  'ARDAGPDQLLWLSDYHYMDV': {'ADI-15835'},
  'GRDHVALLSAIFEPQYWIDP': {'ADI-16012'}},
 ('IGHV1-24', 19): {'ATAICRGGSCYYYHYGMDV': {'2.1.7F12'}},
 ('IGHV3-30-3', 18): {'ARDRGDIVVVVPANYFGP': {'2.1.7G01'},
  'ASDTSSHYSSLLYNWFDS': {'5.6.c2609'},
  'ARGPQEFSWLAAVGTVDS': {'ADI-15755'},
  'AREKRFLEWLSVGDAFDI': {'ADI-15899'}},
 ('IGHV3-30', 18): {'ARDRGDIVVVVPANYFGP': {'2.1.7G01'},
  'ASDTSSHYSSLLYNWFDS': {'5.6.c2609'},
  'AKESFSGRQLLVPWSFDF': {'ADI-15924'},
  'AKERSRSWYTWASGYFEY': {'6650'}},
 ('IGHV4-39', 19): {'ARIVGATRGYYYYYHGMDV': {'2.1.7H11'},
  'VRQSSVPYFDWSSPGQIDP': {'5.6.c2931'},
  'ARSEEDSVFGVLKGLAFDI': {'5.6.c3021'},
  'ARHGYGDYLLTHYHFGLDV': {'ADI-16017'}},
 ('IGHV3-48', 20): {'AKKGWQSTFLGMDYFYGMDV': {'2.10.1E06'},
  'ARLYSSSWKNLHLHYYGMDV': {'5.1.5G07'},
  'ARTDPPRGGMVLYAEEWFDP': {'ADI-15787'},
  'ARKRGIYGLLIGPEDDAFDI': {'ADI-15903'},
  'AKLGAPEQWLVSSKESYFDY': {'ADI-16013'},
  'ARENSDFISSLLYYSYGMDV': {'EV120-1-A10'}},
 ('IGHV3-11', 16): {'ARWTDSSSWNGGQFDY': {'2.10.1F05'},
  'ASTTWLYDSSGYYPDY': {'EBOV-1161'}},
 ('IGHV3-11', 17): {'ARDHEPATAILSGWFDP': {'2.6.1A08'},
  'AGGVQRGYNYYYYGMYV': {'9.1.c1617'},
  'ARDSMVQGVFIHGPNDY': {'ADI-15945'},
  'ARDLLWFGEEPHWYFDL': {'6537'}},
 ('IGHV4-30-2', 11): {'ASSGSSYGFDY': {'2.6.2A10'}},
 ('IGHV3-53', 16): {'ARTIVVTIIGSWYFDL': {'5.1.10D11'},
  'ARVASSAGTFYYGMDV': {'5.6.1A02'}},
 ('IGHV1-69', 16): {'ARDLSGMVGSNDAFDI': {'5.1.10D12'},
  'AREHGDDIYYYFAMDV': {'5.6.c3133'}},
 ('IGHV3-43', 24): {'AKGIYVLRFLEWLRWGNYYYRLDV': {'5.1.11A12'}},
 ('IGHV4-59', 15): {'ARHISLAAAGTGFDY': {'5.1.11B03'},
  'ARDRSTEWLFYGMDV': {'5.1.5E04'},
  'ARLSHSEWLFGAFDI': {'5.6.2C02'},
  'ARIVGDEIFFYGLDV': {'5.6.c2773'}},
 ('IGHV3-13', 10): {'ARVRWLQFDY': {'5.1.11D02'}, 'ARARWLQFDN': {'5.6.c2875'}},
 ('IGHV3-73', 20): {'TRTPPDQMYFRAQYYYAMDV': {'5.1.11E04'}},
 ('IGHV3-21', 16): {'ARAPPSRYNWNDAFDY': {'5.1.12A05'},
  'AGPQGGSGSYHYGMDV': {'5.1.5A05'},
  'ARDLSEYQLLLSYFDY': {'9.1.c1410'},
  'AGAEYSYGFGVDAFDI': {'ADI-15800'},
  'ARAVGELLFYTDAFDI': {'ADI-15902'},
  'ARTLGDSLLYLDAFDI': {'ADI-15936'},
  'ARDLGDILIVPAAFDY': {'ADI-16037'}},
 ('IGHV4-34', 26): {'ARGLRRVGWRSSGWYDRVVPNYYLDY': {'5.1.12A11'}},
 ('IGHV5-51', 13): {'ARLKGGLKRELDY': {'5.1.12C07'},
  'ARTRSFYTGGFDY': {'5.1.1G10'}},
 ('IGHV1-69', 13): {'ARDLGVVTTSGDT': {'5.1.12C09'},
  'ARAAAGKNNWFDP': {'5.1.1A03'},
  'ARDLGTVLTPGDS': {'5.6.c2957'}},
 ('IGHV3-11', 22): {'ARPIRASGYYYDRSGGLYGMDV': {'5.1.12F04'}},
 ('IGHV3-15', 18): {'TTEIMATIGLFYYFGMDV': {'5.1.12H04'}},
 ('IGHV3-49', 13): {'SSEAAAGLKYFDL': {'5.1.1A06'}},
 ('IGHV5-51', 14): {'ARSRIAAAGDAFDI': {'5.1.1C10'}},
 ('IGHV4-39', 21): {'ARFSAYHYDSSGYYATYHFDY': {'5.1.1D11'},
  'ARLSGVVVVPPALRYYYGMDV': {'5.1.1H05'},
  'ARPGTTVTTSWGTGYYYYMDV': {'ADI-15801'}},
 ('IGHV4-61', 17): {'ARVRGNPDLYYNFGMDV': {'5.1.1E11'},
  'ATELYYYGSGSYDPLWS': {'BDBV386'},
  'ARGPVSYYSGNLYYFDY': {'BDBV340'}},
 ('IGHV4-39', 10): {'GRMLPGPITH': {'5.1.1H04'}},
 ('IGHV1-69', 12): {'ARATSLGYTFAS': {'5.1.2A03'}, 'AGGSSWLYYMDV': {'142'}},
 ('IGHV3-15', 17): {'TTDACARTSCRYQDFDY': {'5.1.2C06'},
  'TTGSYLSYHSGSGYLDI': {'6532'},
  'IPTAYYDYVWGSYRSDY': {'66-6-14'}},
 ('IGHV1-69', 22): {'AIDVVRGRSGYSYGFRVYGMDV': {'5.1.2C10'},
  'ARDLEWLGYCTGGVCYASSMDV': {'ADI-15981'},
  'ARGQGEIVVMVGHDDGGDYLGY': {'BDBV342'}},
 ('IGHV3-74', 17): {'ATGHSSGWYYYYYGMDV': {'5.1.2C12'}},
 ('IGHV1-46', 19): {'ARALGDSSSWSTISNWFDP': {'5.1.2E10'},
  'ARDLPTTIFGVIHPYAMDV': {'9.6.3A03'}},
 ('IGHV4-59', 12): {'ARQWGFYGGTDF': {'5.1.5A01'}},
 ('IGHV3-53', 22): {'ARELLGGDFWSGHYGDYYGMDV': {'5.1.5A02'}},
 ('IGHV3-53', 20): {'ASRLITIFGVLGDYYYGMDV': {'5.1.5A07'},
  'ARDRLLWFTELLYRDNGMDV': {'ADI-15803'}},
 ('IGHV4-30-4', 15): {'ATDYGDLFYYYGMDV': {'5.1.5A08'},
  'ARGYSSGWYLAYFQH': {'9.1.c1426'}},
 ('IGHV3-43', 17): {'SKDISPFHTFWSGYPDS': {'5.1.5A12'},
  'AKEYTSSAGLYYYGVDV': {'5.1.5E03'},
  'AKEIGGSSELFYYGLDV': {'5.1.8B07'},
  'VKNLDSRSSIFYYGLDV': {'5.6.1B05'},
  'AKDAVDNSGLYYYGMDV': {'5.6.c3151'}},
 ('IGHV3-66', 15): {'ASFRDGYPYYYGMDV': {'5.1.5C01'}},
 ('IGHV1-3', 17): {'ASALLWFGESPSYYFDY': {'5.1.5C03'}},
 ('IGHV4-34', 23): {'ARGVREYSGYDSQYYYYYYGMDV': {'5.1.5C09'},
  'ARGPRGYCPNGVCHWYYHYGMDV': {'9.6.3E05'}},
 ('IGHV3-30-3', 15): {'AREGGYNFYYYGMDV': {'5.1.5D06'},
  'AREGHTSGFCGCFDY': {'9.6.1G01'},
  'ARWGGNIYGSLGLDV': {'ADI-15813'}},
 ('IGHV4-34', 14): {'ARGPGTPPRGAFDI': {'5.1.5E06'},
  'ASLTRSSWFRAFDY': {'5.6.c2517'}},
 ('IGHV3-48', 13): {'ACIAAPGRFHFDY': {'5.1.5E09'},
  'ARGHNNWFLYFDS': {'5.6.c3168'},
  'ARAAADYNYGMDV': {'ADI-15778'}},
 ('IGHV1-69', 21): {'ASDYDSSGYYYEGRYYYAMDV': {'5.1.5E11'},
  'ARLVWDIVILPGSTAYYYMDV': {'ADI-16044'},
  'ARQINEMATFGEIHYYTYMDV': {'BDBV289'}},
 ('IGHV4-4', 14): {'ARDMGWLQGTYFDY': {'5.1.5E12'},
  'ARTGGWGSSTDWDY': {'5.1.7A06'},
  'ARDLGWLVHGYFDP': {'5.6.c2569'}},
 ('IGHV3-21', 14): {'ARLFGELLFYGMDV': {'5.1.5F11'},
  'ASPSGSDHYYGMDV': {'5.1.6A02'},
  'SRADWDSGKGDLDS': {'BDBV255'},
  'ARGGSIAARSPFDY': {'EBOV-1171'}},
 ('IGHV3-43', 8): {'ASLYYFDY': {'5.1.5G02'}},
 ('IGHV4-30-4', 18): {'AAWRVGMADLYYYYGMDV': {'5.1.5G04'},
  'ARGPKSLAGIAMTGAFDY': {'ADI-16028'},
  'ARGPKSLSGIAMAGAFDY': {'ADI-16038'}},
 ('IGHV3-7', 17): {'ARLAAVGTWFYLFYSDN': {'5.1.5G05'},
  'VRDQVQEEFFYVYYFDS': {'5.6.1E07'}},
 ('IGHV3-7', 20): {'ARASSRDSESEIFYSYGMLD': {'5.1.5G11'},
  'ARSQLEGLGDLFYYNFGLDV': {'5.6.c2633'},
  'ARGPPPAAPEDLFYNYTMDV': {'5.6.c3166'},
  'ARLGTEWFRDLLYYDYGLDV': {'ADI-15789'}},
 ('IGHV3-7', 25): {'ARHLNSPDYGDYAGMLFYYYYGMDV': {'5.1.5H06'}},
 ('IGHV3-33', 17): {'ARDLTRFDDFWSGYWSY': {'5.1.5H08'},
  'VRDFYELTPTDYYGMLD': {'5.1.6H02'},
  'ARDGAANFDFWMGWFDP': {'5.1.8B10'},
  'ARDSSAPAAIFYDAFDM': {'5.6.c2687'},
  'AREAAIVGAIFYDGMDV': {'5.6.c3108'}},
 ('IGHV3-9', 20): {'AKEMGDSKTIFGHIYYGLDV': {'5.1.6A03'}},
 ('IGHV3-15', 20): {'TTVGQYYDFWSGYSVYYFDY': {'5.1.6A08'},
  'AAGPIKEYHDFLTGYYEVDY': {'ADI-15735'},
  'TTDHLAVYDDFLTGYYDIDY': {'ADI-15898'}},
 ('IGHV3-30-3', 17): {'ARDCHEPSAIFSDAFDI': {'5.1.6B08'},
  'ARDPASPSDIFQDAFDI': {'5.6.c3557'}},
 ('IGHV3-43', 18): {'AKGSLVESQLLSYYYFDY': {'5.1.6B10'},
  'AKEGGPDSSTFYYYGMDV': {'5.6.c2998'},
  'AKDGGSTLTTLLYNWFDS': {'5.6.c3507'}},
 ('IGHV4-30-2', 14): {'ASFMTTVTTGWFDP': {'5.1.6C05'}},
 ('IGHV3-53', 17): {'ATETGTTDLFYYYGLDV': {'5.1.6D05'}},
 ('IGHV3-53', 13): {'ASFRLPYYYGMDV': {'5.1.6D09'},
  'ARISSSSSWYFDL': {'5.1.7C03'}},
 ('IGHV3-7', 21): {'ARAWDGSGSFGSLFYYYGMDV': {'5.1.6E09'},
  'AKTLAAAAPGDLFYYYYAMDV': {'5.1.7A01'},
  'ARDHVVEVPGAIFYNYYGMDV': {'5.1.8C03'},
  'ARVGALLWFRDLLFIDYGMDV': {'ADI-15771', 'ADI-15931'}},
 ('IGHV3-49', 23): {'TREGIVVVPAAILDYYYYYGMDV': {'5.1.6G01'}},
 ('IGHV3-74', 13): {'VRRTSTGWWGIDY': {'5.1.6G06'}},
 ('IGHV3-74', 15): {'ARSSYYGSASFAFDI': {'5.1.6G07'}},
 ('IGHV3-21', 21): {'ARDDDYYDSGSYLFYEYYFDY': {'5.1.6G09'},
  'ARDIYDSGGYYYGGGTDAFDI': {'ADI-15915'},
  'ARDGALPADFVLLPAVNCFDP': {'ADI-15955'},
  'AREGSSSTILTPVDYYYGMDV': {'66-6-19'}},
 ('IGHV3-21', 11): {'ARWETVTNFDY': {'5.1.6G11'}},
 ('IGHV3-7', 26): {'ARIGYCSGGNCYSDGDLFYYYFAMDV': {'5.1.6H07'},
  'ARVVQIDSSIILVPAAINDYYYGMDV': {'6658'}},
 ('IGHV3-49', 24): {'TRDSDYYYDSSGYYFMRAEYFLDY': {'5.1.7A04'}},
 ('IGHV3-30', 16): {'AKDVPPLGDFWSGYFH': {'5.1.7A11'},
  'AKGWLQNHYYYFNMDA': {'5.6.1C10'},
  'AKGEAYYDILTGNIDM': {'9.1.c2296'}},
 ('IGHV3-30-5', 16): {'AKDVPPLGDFWSGYFH': {'5.1.7A11'},
  'AKGWLQNHYYYFNMDA': {'5.6.1C10'},
  'AKGEAYYDILTGNIDM': {'9.1.c2296'}},
 ('IGHV3-66', 17): {'ARGGLWFGEFLLPGFDY': {'5.1.7B03'},
  'ARAGGCGGDCYSYYFDY': {'5.6.c3295'},
  'ARAGGVVVTAIRTTFDY': {'5.6.c4013'},
  'ARMETCIAIICDWYFDL': {'EV035-2-C10'}},
 ('IGHV3-15', 27): {'TTDGVGYYFGSGSYSRRHYYYYFAMDV': {'5.1.7B05'}},
 ('IGHV1-3', 16): {'ARDGGTWSGYYGLLDY': {'5.1.7B07'},
  'AREGGFGELLYHGMDV': {'5.1.8B12'}},
 ('IGHV1-46', 12): {'ARVWYFDWLLDY': {'5.1.7C10'}},
 ('IGHV3-33', 16): {'ARESDASDILTGYLDY': {'5.1.7D01'},
  'ARADSTDDYYYYYMDV': {'ADI-15868'},
  'ARESIRVGDTRSYFDY': {'ADI-15971'}},
 ('IGHV3-9', 13): {'AKDRGAAAGVFDH': {'5.1.7D12'}},
 ('IGHV3-74', 19): {'ARDGRAFLEWLLSGYGMDV': {'5.1.7E03'},
  'SRGFEDTTLVAFAVSGYHF': {'ADI-15796'}},
 ('IGHV3-15', 5): {'STRRD': {'5.1.7E06'}, 'ITTYY': {'EV058-1-A6'}},
 ('IGHV1-18', 16): {'ARDGAQRGSGYYYSEY': {'5.1.7F01'},
  'ARDGTVTTVYYYGMDV': {'5.1.7F04'},
  'ARGEEYSTLYFYGMDV': {'5.6.c3191'},
  'ARHFHYYDSSGSETDY': {'140'}},
 ('IGHV3-33', 13): {'ARTPGYSSAWYDY': {'5.1.7F10'},
  'ARDPDGEIVEAPP': {'5.1.8B05'},
  'ARGNGYSSGWLDN': {'5.6.c3053'}},
 ('IGHV3-48', 23): {'ARENCGGDCYSVFSVLSNYGMDV': {'5.1.8E04'}},
 ('IGHV3-11', 6): {'ARGDGY': {'5.1.8E11'}},
 ('IGHV4-31', 16): {'ARTPSVFRFLEWSMDV': {'5.6.1B06'}},
 ('IGHV1-3', 21): {'ARDGTYCSGGSCMYYYHGMDV': {'5.6.1B07'}},
 ('IGHV3-53', 19): {'ARDLAWGSGSSRYYYGIDV': {'5.6.1C07'}},
 ('IGHV1-3', 19): {'AREGGLIPAGTLGIDWFDP': {'5.6.1D06'},
  'ARAPDDSIGMLTAYGPLDH': {'ADI-15744'},
  'ARHFPLYFGSGNYSYYMDV': {'ADI-15805'}},
 ('IGHV3-66', 18): {'ARGGITFGGVLDDNYFDP': {'5.6.1G04'}},
 ('IGHV3-33', 18): {'AREPYSIHDLFYYYAMDV': {'5.6.2A10'},
  'ARDPGHPSDLYYYYGMDV': {'5.6.c3014'}},
 ('IGHV4-39', 17): {'ARLSTTPGLGFYYGMDV': {'5.6.2B06'},
  'ARLKSTDNDFWNGYPDY': {'ADI-16048'},
  'ASIYGSGTFYYYFYMDV': {'MR78'}},
 ('IGHV1-46', 22): {'ARAPRVRDQLFSLQASTGAFDY': {'5.6.2B09'},
  'ARDPPRLDFWGNSPTFGYGMDV': {'9.6.3A04'},
  'ARETSKHDFWSGSPYHYYYMDV': {'ADI-15995'}},
 ('IGHV3-64', 17): {'ASVYNGGDEIYYYGMDV': {'5.6.2B11'}},
 ('IGHV4-4', 15): {'ASQDRYSWAGNGLDV': {'5.6.2C04'},
  'ARDPGRGRDYYEMDV': {'ADI-15741'}},
 ('IGHV3-30', 28): {'VKELHPPLYNDFWSGSSPKAYYYYGMDV': {'5.6.2D07'},
  'AKEPLPARGDFWSGHYSPPSYYYYGMDV': {'5.6.c3057'}},
 ('IGHV3-30-5', 28): {'VKELHPPLYNDFWSGSSPKAYYYYGMDV': {'5.6.2D07'},
  'AKEPLPARGDFWSGHYSPPSYYYYGMDV': {'5.6.c3057'}},
 ('IGHV3-33', 15): {'ARVGLQFAGAWYFDI': {'5.6.3A03'},
  'AREGWQQLVLMGFDY': {'EV035-2-B8'},
  'ARQATLSGSYYYFDY': {'EV136-1-D7'}},
 ('IGHV3-66', 12): {'ARIYFYYNGMDA': {'5.6.3B12'},
  'ARIYFFYNGMDV': {'5.6.c3010'}},
 ('IGHV4-39', 13): {'VTTLDFGNYGMDV': {'5.6.c2458'},
  'ARVESWQLGAFDI': {'6651'},
  'ARPYTSGWSGVDY': {'66-6-13'}},
 ('IGHV4-39', 15): {'ARHRSDQMLFYWFDP': {'5.6.c2460'},
  'ARLAYGSGWAGWFDP': {'5.6.c2762'},
  'VRHLSTELLFGCFDP': {'9.1.c1482'},
  'ARQYSSGWSWGWFDP': {'ADI-15873'}},
 ('IGHV4-39', 18): {'ARGGVIVLMVYAIVPPDV': {'5.6.c2481'},
  'ARADMLQGIIITRVAFDY': {'ADI-15856', 'ADI-15872', 'ADI-15874', 'ADI-16049'},
  'ARADMLHEFIINRVAFDY': {'ADI-16025'}},
 ('IGHV2-26', 17): {'ARIQSSEWIYYYYGMDV': {'5.6.c2485'}},
 ('IGHV3-48', 16): {'ARDTETTGLYYYGMDV': {'5.6.c2617'},
  'ARVDSYYGILTGYPDY': {'ADI-15965'},
  'ARVPYYGILTAGYFDY': {'ADI-15994'}},
 ('IGHV1-69', 20): {'ARCRSGFKDPSGYFYYAMDV': {'5.6.c2627'},
  'AREVGDMIGVILYTYYYMDV': {'ADI-16008'},
  'ARDVIGSHSGSSWAYYYFDY': {'EBOV-1172'}},
 ('IGHV1-46', 15): {'AREKSRDFDWELFDY': {'5.6.c2636'},
  'ARDRAQAGTNNWFDP': {'ADI-15842'}},
 ('IGHV4-34', 19): {'ATSTLDSSSVFYYSYGLDV': {'5.6.c2670'},
  'ARGRVHSTSVIYHFYGMDV': {'ADI-15749'},
  'ARGSHAYYDILTGPKPFDY': {'ADI-15793'},
  'ARGPQSFYDLLTGLNPPDS': {'ADI-15918'},
  'ARGTYKDIGVLIAATYYDH': {'ADI-16063'}},
 ('IGHV4-4', 26): {'ARHRLNAEMYCSGGSCYPADSNWFDP': {'5.6.c2686'}},
 ('IGHV2-70', 16): {'ARIRYTSDWFYDAFDI': {'5.6.c2692'},
  'ARIFTSSDWFYDAFDL': {'5.6.c3054'}},
 ('IGHV4-34', 16): {'ARGLEDTALLADAFDI': {'5.6.c2724'},
  'ARRLQRHGNYVGSFDY': {'ADI-15908'},
  'VRGPPGWYSSDWPIDY': {'ADI-16005'},
  'TSRIRSHIAYSWKGDV': {'BDBV223'}},
 ('IGHV4-31', 21): {'ARAYCGGDCYSLLYYYYGMDV': {'5.6.c2725'},
  'ARDRYNTDYGNVLYYFYGMDV': {'ADI-15867'}},
 ('IGHV4-59', 20): {'ASGVPEDNSQILYYYYGMDV': {'5.6.c2798'},
  'AGDQGFCTNGVCFRVGWFDP': {'ADI-16060'}},
 ('IGHV4-4', 20): {'ARARHDDSNTFLWFVYGMDV': {'5.6.c2824'},
  'ARERLLWLKNLLYNENGLDV': {'ADI-15928'},
  'ARLNSITLVRGVEGYYYMDV': {'ADI-16034'}},
 ('IGHV5-10-1', 26): {'ARHSWVQNSAYDPQMISYDHYYGMDV': {'5.6.c2828'}},
 ('IGHV4-30-4', 17): {'ARVEGNEILFSLWYFDI': {'5.6.c2902'}},
 ('IGHV3-7', 22): {'ARLHGGGFSDSDLFYYDFAMDV': {'5.6.c2913'},
  'EGKVVGRTAAATANYYYFYMTS': {'EV063-3-D8'}},
 ('IGHV4-31', 14): {'ARGRGEMLTGYFDY': {'5.6.c2954'},
  'ARGSVSVLFGELDV': {'5.6.c2961'},
  'ARVPGARIGITFDI': {'ADI-15972'},
  'AGALLRYFDWAIDP': {'EV035-2-B5'}},
 ('IGHV4-30-4', 21): {'ARDRIQVVPDGIVHYYYGMDV': {'5.6.c2972'}},
 ('IGHV3-7', 15): {'AREPAGFVFEGGFDY': {'5.6.c3067'},
  'AREEDVNIAMGALGY': {'ADI-15969', 'ADI-15984'}},
 ('IGHV3-30', 14): {'AKDLGSNGWYYFDS': {'5.6.c3221'}},
 ('IGHV3-30-5', 14): {'AKDLGSNGWYYFDS': {'5.6.c3221'}},
 ('IGHV3-21', 17): {'ARESVDDTSMLYYGLDV': {'5.6.c3225'},
  'ARDGAVDTDIYYYGMDV': {'5.6.c3360'},
  'ARALSMGELFVAGTIDY': {'ADI-15733'},
  'AREAWDLDIVATILLDY': {'ADI-15821'},
  'ARDLRYFDWLYHDAFDI': {'ADI-15831'},
  'ARDLSFGGIIFINAFDL': {'ADI-16009'},
  'ARDMGYCSGGSCPNFDF': {'2G1'}},
 ('IGHV4-61', 16): {'AGTVIQGVVSFDWFDP': {'5.6.c3236'}},
 ('IGHV4-59', 13): {'ARGGGWYDNWFDP': {'5.6.c3242'}},
 ('IGHV3-11', 14): {'ARNVEQIVGATLDY': {'5.6.c3250'},
  'ARVAHGYDSYYFDH': {'ADI-15962'}},
 ('IGHV4-59', 16): {'ARHYGVGTYSGGWFDP': {'5.6.c3397'},
  'ARHTPIRYSSGWYLDY': {'ADI-15820', 'ADI-15901'},
  'ARLGRLITGTLWYSDY': {'ADI-15976'}},
 ('IGHV3-30', 30): {'AKGFLERNFDLWSGSYSDSGWRGPYYGMDF': {'5.6.c3412'}},
 ('IGHV3-30-5', 30): {'AKGFLERNFDLWSGSYSDSGWRGPYYGMDF': {'5.6.c3412'}},
 ('IGHV3-11', 20): {'ARDRCDRDQLLCYYYYGMDV': {'5.6.c3479'},
  'ARASYCGGDCYFLLSSRFDY': {'6535'}},
 ('IGHV1-18', 25): {'TRDSFCAGSNSCYLWAGYYYYAMDV': {'5.6.c3835'}},
 ('IGHV3-48', 12): {'ARVYMRTFYFDN': {'5.6.c3955'},
  'ARIPQAAFHFDY': {'5.6.c4516'}},
 ('IGHV4-4', 16): {'ARDQGHWNPGKGAFDI': {'5.6.c4172'},
  'ARDRAVSINYYYYMDV': {'ADI-15975'},
  'ARGASSDPNYYYAMDV': {'18-1-D10'}},
 ('IGHV4-39', 16): {'ARSLEAHLLYYYAMDV': {'9.1.c1500'}},
 ('IGHV4-4', 12): {'ARGDQLIYYFDY': {'9.1.c1533'},
  'ASEYYGSGTYGV': {'ADI-15812'}},
 ('IGHV5-10-1', 17): {'AREVAGEEIFYYYYMDV': {'9.1.c1853'}},
 ('IGHV3-21', 8): {'ARGSTGGY': {'9.6.3A06'}},
 ('IGHV3-23D', 22): {'AKEGSPLSDVLLVAAPFGWFDP': {'9.6.3D06'},
  'ARGGEMATSSWGYGYYYYYMDV': {'ADI-15746'},
  'AKVGMTAVTKGMEIDYSYGMDV': {'ADI-15768'}},
 ('IGHV3-23', 12): {'AKHYSGRYCQDS': {'9.6.3D08'}},
 ('IGHV3-23D', 12): {'AKHYSGRYCQDS': {'9.6.3D08'}},
 ('IGHV1-18', 13): {'ARSGYSIRRYFDY': {'9.6.3D12'},
  'ARTAPGGRGVHDY': {'EV035-2-C6'}},
 ('IGHV3-15',
  22): {'TTYTEDMRYFDWLLRGGETFDY': {'ADI-15946',
   'EP3583122_38_PE-64'}, 'TTDTLRDNYDDILTGYYRGFDY': {'EBOV-1166'}},
 ('IGHV3-49', 19): {'TRDREQTWFGELASSPLDY': {'ADI-15731'},
  'TRDGFRGSSWGYSYYGMDV': {'ADI-15750', 'EP3583122_34_PE-05'}},
 ('IGHV4-34', 17): {'ARGKSSTVVSRTTHFDY': {'ADI-15734'},
  'ARGRRNIWLVPNYSVDV': {'ADI-15783'},
  'ARGRSSTVVSRTTHFDY': {'ADI-15947'},
  'ARGPIVVMVFVARPFDY': {'ADI-15963'},
  'ARALRTIWDGYYNYMDV': {'ADI-16062'},
  'ATKMGGYGDYWHWYFDL': {'6541'}},
 ('IGHV3-30', 20): {'VTGGDLVVLPASMDYYGMDV': {'ADI-15736'},
  'ARGGDIVVVVTSTDYYGMDV': {'66-3-7C'}},
 ('IGHV3-30-5', 20): {'VTGGDLVVLPASMDYYGMDV': {'ADI-15736'}},
 ('IGHV3-21', 18): {'AREGITLGGVLVINALDI': {'ADI-15737'},
  'AREGITIFGVLIHPVMDV': {'ADI-15825'},
  'ASEEITIFGVLFHPVMDV': {'ADI-15849'},
  'ARDLGHGVSYGYGTYYDY': {'ADI-15854'},
  'AREGITILGVLIHPVMDV': {'ADI-15863'},
  'ARPITILQGVLIVDAFDI': {'ADI-15940'},
  'AREEITISGVLVHPVMDV': {'ADI-15959'},
  'ARDVTDSSGYLYLNAFDL': {'ADI-16056'},
  'VREGPRATGYSMADVFDI': {'KZ52'}},
 ('IGHV3-33', 23): {'AREGAVRLDYNILTGYYLSSFDI': {'ADI-15738'},
  'ARALLVPAAMPWSVLFYYFGMDV': {'139'}},
 ('IGHV3-48', 24): {'ARHNSGLSGGGILYDYVWGSPLDY': {'ADI-15740'}},
 ('IGHV4-34', 15): {'ARALPRGGNYRTFDY': {'ADI-15743', 'ADI-15977', 'ADI-16031'},
  'ARALPRGGNYRTFEY': {'ADI-15839'},
  'ARAWLRSRGYPSFDY': {'ADI-15843', 'ADI-15912'},
  'ARAWLRSSSYPSFDY': {'ADI-15861'},
  'TKVGSWNVGGMAFHI': {'ADI-15952'},
  'ARAWLRTSWYPSFDY': {'ADI-15978'},
  'ASMNTFGGIMDPFDY': {'6538'}},
 ('IGHV3-64D', 17): {'VKLTIGAARVTGYYFDY': {'ADI-15745'},
  'VKDLEGSPYIQLWLLGY': {'ADI-15992'}},
 ('IGHV3-66', 21): {'ASASPADSSGWGLAYYFYMDV': {'ADI-15747'}},
 ('IGHV5-51', 22): {'ARQAREEYYDFWRGYYSSPFDI': {'ADI-15748'}},
 ('IGHV4-34', 25): {'ARGVAFLSDSSGYPVLFLVGPGFDY': {'ADI-15752'},
  'TRGRRIPFHYRGFSYGYEYYYYMDV': {'EBOV-1144'}},
 ('IGHV5-51', 17): {'ARGLVAAPGSMSDWFDP': {'ADI-15753'},
  'ARHPPHAGSYYYHGMDV': {'EBOV-1139'}},
 ('IGHV3-64', 18): {'ARGGAVAGPLYADWYFDL': {'ADI-15754'}},
 ('IGHV1-2', 22): {'ARVSRGDPYNYDSSGYYGAFDY': {'ADI-15757'},
  'ATPAPIVGATRGYYYHYYGMDV': {'ADI-15983'}},
 ('IGHV1-46', 16): {'ARDRYPTVVNYFGMDV': {'ADI-15758'},
  'ARDLMGWQHNLGGFDY': {'ADI-15759'},
  'ARDRYPTVVKYFGMDV': {'ADI-15956'},
  'ARDRYPTVTKYFGMDV': {'ADI-15974'}},
 ('IGHV1-18', 22): {'ARDVEIAVVAVATLSRNFGMDV': {'ADI-15761'},
  'ARDTAFMFASFGVGYHYNGMDV': {'ADI-15870'}},
 ('IGHV3-48', 22): {'ARTLGYCSGGSCYSVSHDAFDI': {'ADI-15762', 'ADI-15818'},
  'ARGRNDYVWGSFRRDYYYYMDV': {'ADI-15798'}},
 ('IGHV3-21', 22): {'ARAGGSGTSDGMDYYYYSGMDV': {'ADI-15769'},
  'ARGDDFLVVAGTIDYSHYVMDV': {'ADI-15791'},
  'ARDAPITSSWGTGYYDYYYMDV': {'ADI-15929'},
  'ARDHKEYISDWGVGYYYSGMDV': {'ADI-15993'},
  'ARGDDFVVVAGTIDYSHYVMDV': {'ADI-16042'},
  'ARENLWFGELLSHYDYYYAMDV': {'6661'},
  'ARVPFPDLLTGDYLLGYYYMDV': {'EBOV-1149'}},
 ('IGHV5-51', 21): {'ARGRGQEFTTVLVVVTPYFDV': {'ADI-15773'}},
 ('IGHV1-69', 17): {'ASGRTISGVLITDYFIF': {'ADI-15775'},
  'AREETIGGIVVSQFFDP': {'ADI-15922'},
  'AILGTFNWKSGGNYFGP': {'1C3'}},
 ('IGHV1-69D', 17): {'ASGRTISGVLITDYFIF': {'ADI-15775'}},
 ('IGHV2-70', 15): {'ARTMYYYGSGSYTDY': {'ADI-15779'}},
 ('IGHV5-10-1', 9): {'AKTFYDTDY': {'ADI-15781'}},
 ('IGHV4-4', 23): {'ARFTDWYYDILTGKKEDFYYIDV': {'ADI-15782'}},
 ('IGHV4-30-2', 12): {'ARGDWLGDYFDY': {'ADI-15786'}},
 ('IGHV1-2', 17): {'ASGITILGILMHDAFDI': {'ADI-15788'},
  'ARVNYYDSSGYYGWFDP': {'ADI-15845'},
  'ARVNHYDSSGYYGWFDP': {'ADI-15941'},
  'AREEGRNSLRYYYGMDV': {'ADI-15980'},
  'ARGDLETTIFFYNAVDV': {'BDBV91'},
  'ARDYVRWMATIGDAFDI': {'56-3-7A'}},
 ('IGHV4-61', 22): {'ARDREVVPGLSGLLYSFHGMDV': {'ADI-15792'}},
 ('IGHV3-74', 27): {'ARELTVNYPGSGSSFMVGTYYHYALDV': {'ADI-15799'}},
 ('IGHV5-10-1', 20): {'ARHGYFDWLFLPHYYYAMDV': {'ADI-15802'},
  'ARRDVLDISPWLHPADWFDP': {'ADI-15930'}},
 ('IGHV3-33', 22): {'ARDGTYYYGSGSEHWDYYGLAV': {'ADI-15808'},
  'ARDPLSDGFLSLSNHFYYGMDV': {'45-4-B10', 'P6'}},
 ('IGHV2-5', 23): {'AHIGGKDYYHSFGSYYQTHAFDI': {'ADI-15809'}},
 ('IGHV3-7', 9): {'ARGDGVFDY': {'ADI-15816'}},
 ('IGHV1-18', 24): {'ARDSTLLAYSGYDNTIFLHNGMAV': {'ADI-15817'},
  'ARDRGTFTYVSGLVVAAYLDAFDI': {'ADI-15864'},
  'ARDVLRFLEWLLHLRTNDYNGMDV': {'ADI-15937'}},
 ('IGHV4-31', 29): {'ARGLSLGHCTGGLCFTQVGGDYNYYGMDV': {'ADI-15829'}},
 ('IGHV3-48', 18): {'ARGPISRGLLFIDYGMDV': {'ADI-15833'},
  'ARGGLDIGVVIAATAFDI': {'ADI-15892'},
  'ARTGQPSDWLLPPEYFQH': {'ADI-15906'},
  'ARGANYDIWSGFPNWFDP': {'ADI-15920'},
  'ARGNVPPDMLYYYYAMDV': {'ADI-15932'},
  'ARGGYQDDLLVLVTPYDF': {'ADI-15960'},
  'ARGNGDERAVYYYYGMDV': {'ADI-16055'}},
 ('IGHV4-4', 24): {'ARDLRAPTFSWTSRLTPKEKNSDN': {'ADI-15846'}},
 ('IGHV4-31', 12): {'VASFRTVVTPHI': {'ADI-15851'},
  'ARDRIRGGPIDY': {'BDBV399'}},
 ('IGHV3-7', 14): {'ARKGQWGGWSWFDP': {'ADI-15852'},
  'ARDASDFWSPNFDY': {'ADI-15876'}},
 ('IGHV5-51', 11): {'ARRDFWSGTEY': {'ADI-15859'}},
 ('IGHV4-34', 18): {'ARGGLSIPMLRGVQPFDF': {'ADI-15862'},
  'ARSRDYDFWTGHSRFFDY': {'ADI-15950'},
  'ARGERFLEWSLANYYVDV': {'ADI-16000'},
  'ARGPRRFGILIAHNWFDP': {'ADI-16018'}},
 ('IGHV5-51', 25): {'VRHPSLFLHSENDFIAAGRTGWFDP': {'ADI-15866', 'ADI-15885'}},
 ('IGHV2-5', 24): {'ARKRVDQGGEFDIFTGYYDSWFDP': {'ADI-15869'}},
 ('IGHV5-10-1', 22): {'ARHEGGAFSGLILTGYYQPLDY': {'ADI-15875'}},
 ('IGHV3-53', 14): {'ARVTRGYSYGWADY': {'ADI-15879'}},
 ('IGHV3-30', 23): {'AKAGDYIWGSYRYFAGMLKPFDT': {'ADI-15883'},
  'TRGGDIVVLVAESRQEDYNGMDV': {'ADI-15926'}},
 ('IGHV3-30-5', 23): {'AKAGDYIWGSYRYFAGMLKPFDT': {'ADI-15883'}},
 ('IGHV4-4', 18): {'ARLSTSYYDFWSATEFDP': {'ADI-15884'}},
 ('IGHV4-59', 22): {'ARISPITIFGVVTQGFYYFMDV': {'ADI-15887'},
  'ARGQRRDDYNLWLIRVNDAFDM': {'ADI-15990'},
  'ARHHPWGLHGGYGAYNLGWFVP': {'ADI-16041'},
  'ARVRPLFASFGVGRTADDAFDI': {'EV063-3-C2'}},
 ('IGHV5-10-1', 16): {'AVATAGNLYYYYHMDV': {'ADI-15893'}},
 ('IGHV3-48', 21): {'ARDRMPKYDILTGPESAGMDV': {'ADI-15897'},
  'AREYFRSPGSLLRFSGNWFDP': {'ADI-15967'},
  'ASGLRDLGVLLVPADYDGMDV': {'ADI-16016'},
  'ARSKWELLWVVGTNFYYGMDV': {'56-3-7D'},
  'TREDAVTLVRGVVLGPHYFDS': {'EBOV-1136'}},
 ('IGHV4-39', 22): {'ARQDVVVWARELLHSLGGWFDP': {'ADI-15900'}},
 ('IGHV6-1', 13): {'AREWELRYDAFDI': {'ADI-15909'}},
 ('IGHV1-69', 11): {'ARVAGASGSGY': {'ADI-15913'}},
 ('IGHV1-69D', 11): {'ARVAGASGSGY': {'ADI-15913'}},
 ('IGHV4-39', 26): {'ARTVPPDVKIKDILVLVAATEGWFDP': {'ADI-15914'}},
 ('IGHV1-2', 24): {'ATIGPVSIFEVLIPQNYYYYAMDV': {'ADI-15917'},
  'ARGPAADCTGGVCFFLERSDAFDI': {'ADI-16054'}},
 ('IGHV3-48', 19): {'ARGLLSSSMISIINEGFDY': {'ADI-15923'},
  'ARGEETSDIVVLPADAFDI': {'6652'}},
 ('IGHV3-30-5', 18): {'AKESFSGRQLLVPWSFDF': {'ADI-15924'}},
 ('IGHV3-30-3', 23): {'TRGGDIVVLVAESRQEDYNGMDV': {'ADI-15926'}},
 ('IGHV3-33', 9): {'VRGWDHVDY': {'ADI-15933'}, 'ARGWSYVDY': {'ADI-16022'}},
 ('IGHV4-4', 22): {'ATNRGLTFGELLFRDRGEAFDI': {'ADI-15942'},
  'ARDGKRITISGVLIPLYWFFDL': {'56-3-9C'}},
 ('IGHV3-11', 19): {'ARGEGFRELLVKDYYGMDV': {'ADI-15949'},
  'ARVNGYNYGPLTGYHYMDV': {'EBOV-1160'}},
 ('IGHV1-2', 13): {'VVRYFDWNGPFDY': {'ADI-15951'},
  'VVRYFDWNGPIDY': {'ADI-15966'},
  'ARDPTYSSGWRDY': {'EBOV-1132'}},
 ('IGHV4-61', 20): {'ARVQSPFNWNGYYSSLFFDY': {'ADI-15953'}},
 ('IGHV1-3', 23): {'ARGEIPLLVPPAMVRGFYYYMDV': {'ADI-15961'}},
 ('IGHV2-5', 21): {'AHSQTPVSRFLDWSQRLYFDY': {'ADI-15968'},
  'AHVNVITVFGVIIVPSGWFDP': {'ADI-16047'}},
 ('IGHV3-64D', 16): {'VKGGGTTEYYYYGMDV': {'ADI-15979'},
  'VRRYCTSSNCPGLFDY': {'EV063-3-A9'}},
 ('IGHV1-2', 19): {'ARGPGITMLLLAHRYEFDY': {'ADI-15989'},
  'ARGGVVDILTLTFYYAMDV': {'ADI-16024'},
  'ARPLIATRHGRGTSWYFDL': {'56-3-9A'}},
 ('IGHV1-18', 21): {'ARHVWANQWLAENYYYYYMDV': {'ADI-15991'},
  'ARLSHDFGDLGSLFYYFYMDV': {'EBOV-1173'}},
 ('IGHV1-24', 23): {'ATVPPSTIFGVLIKGAQYNWFDP': {'ADI-15997'}},
 ('IGHV3-21', 15): {'ATQLVVGGYYYGMDV': {'ADI-15998'},
  'AREVTMIVVEWYFDL': {'6655'},
  'ARDSGRGGYYKGTDY': {'EBOV-1180'},
  'ASDQGNSTGWEPLGY': {'EV035-2-B2'}},
 ('IGHV3-23', 8): {'AKGRTSSA': {'ADI-15999'}},
 ('IGHV2-5', 30): {'AHSLVAYSNSPVAFGSSWFLSSETTNYFDP': {'ADI-16006'}},
 ('IGHV4-59', 11): {'ARDDYFGGVKI': {'ADI-16019'}},
 ('IGHV1-2', 21): {'ARGNFGRDLLLPAALGGWFDP': {'ADI-16020'},
  'ARELSGDCSGGVCSGSGYFDY': {'ADI-16035'},
  'AREVVVVPTAPTHNFYYYMDV': {'KZ51'}},
 ('IGHV3-11', 18): {'ARGSYCTGVLCTHDAFDI': {'ADI-16032'},
  'ARVNVKFGELLPPYYFDY': {'6672'}},
 ('IGHV3-23', 25): {'TKEFQARLFELLVPASGVSYYGLDV': {'ADI-16033'}},
 ('IGHV4-34', 22): {'ARGPMTTVTTWGIGYYDYGMDV': {'ADI-16040'}},
 ('IGHV5-10-1', 18): {'ARHTYNSDWGTANIAMDV': {'ADI-16051'}},
 ('IGHV3-49', 6): {'IRDVST': {'ADI-16052'}},
 ('IGHV1-3', 18): {'ARGLEDTVVVQELNWFDP': {'ADI-16058'},
  'ARGTMARGLILHYYGMDV': {'176'}},
 ('IGHV3-13', 13): {'VRSDRGVAGLFDS': {'114.24', 'mAb114'},
  'ARAVHSSSAIFDI': {'EBOV-1138'}},
 ('IGHV1-18', 18): {'ARDGGRVLLYFGESGFDP': {'6539'},
  'VRDRSWLATSRPYDAFDI': {'BDBV354'},
  'ARDSHLISIAVANTPNDF': {'BDBV425'}},
 ('IGHV3-73', 18): {'TRHSWLPGAIRNYYYMDV': {'130'}},
 ('IGHV3-53', 23): {'ARGSETGGRGLEWLLYTSPYFDY': {'66-3-2C'}},
 ('IGHV3-74', 21): {'ARGGHYCTDGVCYSLPYFMDV': {'143'}},
 ('IGHV3-15', 7): {'TTEVVGV': {'6669'}},
 ('IGHV3-15', 28): {'TTDQRFEGPVPASNQWLVGYYHYYGMDV': {'66-3-4A'}},
 ('IGHV5-10-1', 12): {'AGSRYYYYGMDV': {'66-3-8B'}},
 ('IGHV5-51', 18): {'ARLGGRVVKVVHAIWFDP': {'18-1-A9'}},
 ('IGHV3-21', 23): {'ARDSQEVFGVLIMAYYDYYYMDV': {'141'}},
 ('IGHV1-3', 22): {'ARGRREMQLVRGSYYYYYYMDV': {'94'},
  'TRGRREMQLVRGSYYYYYYMDV': {'133'}},
 ('IGHV3-15', 12): {'STRYSSAWFNDY': {'6673'}, 'TTVGVHIWNFGY': {'6659'}},
 ('IGHV3-21', 19): {'ARFLGYSYGTNYYYYGMDV': {'66-3-9C'},
  'ARDGPRTVPAAGIGDAFHV': {'EBOV-1176'}},
 ('IGHV4-30-4', 24): {'ARVRFCSGASCASVYLLDLWYFDL': {'125'}},
 ('IGHV1-69', 33): {'ARGLRSLSPRGQEGPTPAPGWRRAQYHYYYMDV': {'BDBV329'}},
 ('IGHV4-61', 19): {'ARVVWGSYRSYHYSYGMDV': {'BDBV335'},
  'ARDPITIFGGVIFGWGMDV': {'BDBV315'}},
 ('IGHV4-61', 15): {'ATSPYYYDSSHYYDY': {'BDBV397'},
  'AGFHCSSGACKAEDY': {'EBOV-1137'}},
 ('IGHV1-69', 23): {'AGHFPQRKPITTIVVITYWSLDL': {'BDBV415'}},
 ('IGHV1-2', 18): {'ARLYGAGSHYNHYNGMDV': {'BDBV353'}},
 ('IGHV4-61', 14): {'ARGGWNLLVSYFDF': {'BDBV432'}},
 ('IGHV4-30', 22): {'ATVTAYSPATMIVVGTEHGFDY': {'BDBV426'}},
 ('IGHV4-61', 21): {'VRDAPWGDFLTGYFGFYGMDV': {'BDBV270'},
  'ARDSGLESLHEWLLPFYAMDV': {'EBOV-1130'}},
 ('IGHV1-8', 24): {'ARGPHVGEVVPGLMAGTYYFPLDV': {'BDBV324'}},
 ('IGHV1-69', 15): {'ARDEIIGARPHWFDS': {'BDBV43'}},
 ('IGHV3-30', 11): {'GRVLYGAAADF': {'BDBV317'}},
 ('IGHV4-30-4', 23): {'ARVRGGRITLGQGDMYYYSGMDV': {'EBOV-296'}},
 ('IGHV3-66', 16): {'ARLLGSGPVFMEYFQH': {'EBOV-1163'}},
 ('IGHV2-5', 15): {'GYFYDTRGYGVYFDY': {'EBOV-1169'},
  'GYFYDTRGHGVYFDY': {'EBOV-1175'},
  'GYFYDTSGHGVYFDY': {'EBOV-1181'}},
 ('IGHV3-49', 21): {'ARVGTYSSSSHIVYYYYGMDV': {'EBOV-1174'}},
 ('IGHV3-11', 7): {'AKGGIWF': {'EBOV-1133'}},
 ('IGHV3-7', 24): {'ARVPDHEGAKWDLLWPTYYHYMDV': {'EBOV-1162'}},
 ('IGHV1-8', 21): {'AREGLIWIGELLYRSHYGMDV': {'EV035-2-D2'}},
 ('IGHV4-38-2', 10): {'VREDTLLLGS': {'EV063-3-B12'}},
 ('IGHV4-38-2', 21): {'AREQGDVAAGGLLYYYYGMDV': {'EV063-3-B5'}},
 ('IGHV3-20', 13): {'ASSVTRHNYGMDV': {'EV120-1-C7'}}}




from setuptools import setup, find_packages

with open('requirements.txt') as f:
    requirements = f.read().splitlines()
  
setup(
    name='clone_search_abs',
    version='0.1',
    packages=find_packages(),
    install_requires=requirements,
)
